@@ -33,10 +33,10 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.Properties;
 import java.util.Set;
 import java.util.Vector;
+import java.util.stream.Collectors;
 
 import org.apache.tools.ant.input.DefaultInputHandler;
 import org.apache.tools.ant.input.InputHandler;
@@ -45,10 +45,9 @@ import org.apache.tools.ant.listener.SilentLogger;
 import org.apache.tools.ant.property.GetProperty;
 import org.apache.tools.ant.property.ResolvePropertyMap;
 import org.apache.tools.ant.util.ClasspathUtils;
-import org.apache.tools.ant.util.CollectionUtils;
 import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.ProxySetup;
-
+import org.apache.tools.ant.util.StreamUtils;
 
 /**
  * Command line entry point into Ant. This class is entered via the
@@ -68,7 +67,7 @@ public class Main implements AntMain {
      * not be seen by Main.
      */
     private static final Set<String> LAUNCH_COMMANDS = Collections
-            .unmodifiableSet(new HashSet<String>(Arrays.asList("-lib", "-cp", "-noclasspath",
+            .unmodifiableSet(new HashSet<>(Arrays.asList("-lib", "-cp", "-noclasspath",
                     "--noclasspath", "-nouserlib", "-main")));
 
     /** The default build file name. {@value} */
@@ -213,12 +212,8 @@ public class Main implements AntMain {
         }
 
         if (additionalUserProperties != null) {
-            for (final Enumeration<?> e = additionalUserProperties.keys();
-                    e.hasMoreElements();) {
-                final String key = (String) e.nextElement();
-                final String property = additionalUserProperties.getProperty(key);
-                definedProps.put(key, property);
-            }
+            additionalUserProperties.stringPropertyNames()
+                    .forEach(key -> definedProps.put(key, additionalUserProperties.getProperty(key)));
         }
 
         // expect the worst
@@ -406,14 +401,8 @@ public class Main implements AntMain {
                 for (final ArgumentProcessor processor : processorRegistry.getProcessors()) {
                     final int newI = processor.readArguments(args, i);
                     if (newI != -1) {
-                        List<String> extraArgs = extraArguments.get(processor.getClass());
-                        if (extraArgs == null) {
-                            extraArgs = new ArrayList<String>();
-                            extraArguments.put(processor.getClass(), extraArgs);
-                        }
-                        for (; i < newI && i < args.length; i++) {
-                            extraArgs.add(args[i]);
-                        }
+                        List<String> extraArgs = extraArguments.computeIfAbsent(processor.getClass(), k -> new ArrayList<>());
+                        extraArgs.addAll(Arrays.asList(args).subList(newI, args.length));
                         processed = true;
                         break;
                     }
@@ -632,8 +621,8 @@ public class Main implements AntMain {
                                      + args[pos]);
         }
 
-        if (threadPriority.intValue() < Thread.MIN_PRIORITY
-            || threadPriority.intValue() > Thread.MAX_PRIORITY) {
+        if (threadPriority < Thread.MIN_PRIORITY
+            || threadPriority > Thread.MAX_PRIORITY) {
             throw new BuildException(
                 "Niceness value is out of the range 1-10");
         }
@@ -660,13 +649,9 @@ public class Main implements AntMain {
             }
 
             // ensure that -D properties take precedence
-            final Enumeration<?> propertyNames = props.propertyNames();
-            while (propertyNames.hasMoreElements()) {
-                final String name = (String) propertyNames.nextElement();
-                if (definedProps.getProperty(name) == null) {
-                    definedProps.put(name, props.getProperty(name));
-                }
-            }
+            props.stringPropertyNames().stream()
+                    .filter(name -> definedProps.getProperty(name) == null)
+                    .forEach(name -> definedProps.put(name, props.getProperty(name)));
         }
     }
 
@@ -798,7 +783,7 @@ public class Main implements AntMain {
                     try {
                         project.log("Setting Ant's thread priority to "
                                 + threadPriority, Project.MSG_VERBOSE);
-                        Thread.currentThread().setPriority(threadPriority.intValue());
+                        Thread.currentThread().setPriority(threadPriority);
                     } catch (final SecurityException swallowed) {
                         //we cannot set the priority here.
                         project.log("A security manager refused to set the -nice value");
@@ -858,12 +843,9 @@ public class Main implements AntMain {
                 System.setErr(savedErr);
                 System.setIn(savedIn);
             }
-        } catch (final RuntimeException exc) {
+        } catch (final RuntimeException | Error exc) {
             error = exc;
             throw exc;
-        } catch (final Error e) {
-            error = e;
-            throw e;
         } finally {
             if (!projectHelp) {
                 try {
@@ -903,11 +885,7 @@ public class Main implements AntMain {
         resolver.resolveAllProperties(props, null, false);
 
         // set user-define properties
-        for (final Entry<String, Object> ent : props.entrySet()) {
-            final String arg = ent.getKey();
-            final Object value = ent.getValue();
-            project.setUserProperty(arg, String.valueOf(value));
-        }
+        props.forEach((arg, value) -> project.setUserProperty(arg, String.valueOf(value)));
 
         project.setUserProperty(MagicNames.ANT_FILE,
                                 buildFile.getAbsolutePath());
@@ -922,7 +900,7 @@ public class Main implements AntMain {
         // Setting it here allows top-level tasks to access the
         // property.
         project.setUserProperty(MagicNames.PROJECT_INVOKED_TARGETS,
-                                CollectionUtils.flattenToString(targets));
+                targets.stream().collect(Collectors.joining(",")));
     }
 
     /**
@@ -941,7 +919,7 @@ public class Main implements AntMain {
         for (int i = 0; i < count; i++) {
             final String className = listeners.elementAt(i);
             final BuildListener listener =
-                    (BuildListener) ClasspathUtils.newInstance(className,
+                    ClasspathUtils.newInstance(className,
                             Main.class.getClassLoader(), BuildListener.class);
             project.setProjectReference(listener);
 
@@ -962,7 +940,7 @@ public class Main implements AntMain {
         if (inputHandlerClassname == null) {
             handler = new DefaultInputHandler();
         } else {
-            handler = (InputHandler) ClasspathUtils.newInstance(
+            handler = ClasspathUtils.newInstance(
                     inputHandlerClassname, Main.class.getClassLoader(),
                     InputHandler.class);
             project.setProjectReference(handler);
@@ -984,7 +962,7 @@ public class Main implements AntMain {
             emacsMode = true;
         } else if (loggerClassname != null) {
             try {
-                logger = (BuildLogger) ClasspathUtils.newInstance(
+                logger = ClasspathUtils.newInstance(
                         loggerClassname, Main.class.getClassLoader(),
                         BuildLogger.class);
             } catch (final BuildException e) {
@@ -1088,13 +1066,10 @@ public class Main implements AntMain {
                 props.load(in);
                 in.close();
                 shortAntVersion = props.getProperty("VERSION");
-
-                final StringBuffer msg = new StringBuffer();
-                msg.append("Apache Ant(TM) version ");
-                msg.append(shortAntVersion);
-                msg.append(" compiled on ");
-                msg.append(props.getProperty("DATE"));
-                antVersion = msg.toString();
+                antVersion = "Apache Ant(TM) version " +
+                        shortAntVersion +
+                        " compiled on " +
+                        props.getProperty("DATE");
             } catch (final IOException ioe) {
                 throw new BuildException("Could not load the version information:"
                                          + ioe.getMessage());
@@ -1146,25 +1121,18 @@ public class Main implements AntMain {
      */
     private static Map<String, Target> removeDuplicateTargets(final Map<String, Target> targets) {
         final Map<Location, Target> locationMap = new HashMap<>();
-        for (final Entry<String, Target> entry : targets.entrySet()) {
-            final String name = entry.getKey();
-            final Target target = entry.getValue();
+        targets.forEach((name, target) -> {
             final Target otherTarget = locationMap.get(target.getLocation());
             // Place this entry in the location map if
             //  a) location is not in the map
             //  b) location is in map, but its name is longer
             //     (an imported target will have a name. prefix)
-            if (otherTarget == null
-                || otherTarget.getName().length() > name.length()) {
-                locationMap.put(
-                    target.getLocation(), target); // Smallest name wins
+            if (otherTarget == null || otherTarget.getName().length() > name.length()) {
+                locationMap.put(target.getLocation(), target); // Smallest name wins
             }
-        }
-        final Map<String, Target> ret = new HashMap<>();
-        for (final Target target : locationMap.values()) {
-            ret.put(target.getName(), target);
-        }
-        return ret;
+        });
+        return locationMap.values().stream()
+                .collect(Collectors.toMap(Target::getName, target -> target, (a, b) -> b));
     }
 
     /**
@@ -1191,7 +1159,7 @@ public class Main implements AntMain {
 
         for (final Target currentTarget : ptargets.values()) {
             final String targetName = currentTarget.getName();
-            if ("".equals(targetName)) {
+            if (targetName.isEmpty()) {
                 continue;
             }
             final String targetDescription = currentTarget.getDescription();
@@ -1227,7 +1195,7 @@ public class Main implements AntMain {
         }
 
         final String defaultTarget = project.getDefaultTarget();
-        if (defaultTarget != null && !"".equals(defaultTarget)) {
+        if (defaultTarget != null && !defaultTarget.isEmpty()) {
             // shouldn't need to check but...
             project.log("Default target: " + defaultTarget);
         }
@@ -1279,14 +1247,14 @@ public class Main implements AntMain {
                                      final String heading,
                                      final int maxlen) {
         // now, start printing the targets and their descriptions
-        final String lSep = System.getProperty("line.separator");
+        final String eol = System.lineSeparator();
         // got a bit annoyed that I couldn't find a pad function
         StringBuilder spaces = new StringBuilder("    ");
         while (spaces.length() <= maxlen) {
             spaces.append(spaces);
         }
         final StringBuilder msg = new StringBuilder();
-        msg.append(heading).append(lSep).append(lSep);
+        msg.append(heading).append(eol).append(eol);
         final int size = names.size();
         for (int i = 0; i < size; i++) {
             msg.append(" ");
@@ -1296,19 +1264,10 @@ public class Main implements AntMain {
                     spaces.substring(0, maxlen - names.elementAt(i).length() + 2));
                 msg.append(descriptions.elementAt(i));
             }
-            msg.append(lSep);
-            if (!dependencies.isEmpty()) {
-                final Enumeration<String> deps = dependencies.elementAt(i);
-                if (deps.hasMoreElements()) {
-                    msg.append("   depends on: ");
-                    while (deps.hasMoreElements()) {
-                        msg.append(deps.nextElement());
-                        if (deps.hasMoreElements()) {
-                            msg.append(", ");
-                        }
-                    }
-                    msg.append(lSep);
-                }
+            msg.append(eol);
+            if (!dependencies.isEmpty() && dependencies.elementAt(i).hasMoreElements()) {
+                msg.append(StreamUtils.enumerationAsStream(dependencies.elementAt(i))
+                        .collect(Collectors.joining(", ", "   depends on: ", eol)));
             }
         }
         project.log(msg.toString(), Project.MSG_WARN);
