@@ -136,9 +136,9 @@ public class ProjectHelper {
             if (name == null) {
                 throw new NullPointerException();
             }
-            for (int i = 0; i < values.length; i++) {
-                if (name.equals(values[i].name())) {
-                    return values[i];
+            for (OnMissingExtensionPoint value : values) {
+                if (name.equals(value.name())) {
+                    return value;
                 }
             }
             throw new IllegalArgumentException(
@@ -146,16 +146,12 @@ public class ProjectHelper {
         }
     }
 
-    /** Default constructor */
-    public ProjectHelper() {
-    }
-
     // -------------------- Common properties  --------------------
-    // The following properties are required by import ( and other tasks
-    // that read build files using ProjectHelper ).
+    // The following properties are required by import (and other tasks
+    // that read build files using ProjectHelper).
 
-    private Vector<Object> importStack = new Vector<Object>();
-    private List<String[]> extensionStack = new LinkedList<String[]>();
+    private Vector<Object> importStack = new Vector<>();
+    private List<String[]> extensionStack = new LinkedList<>();
 
     /**
      *  Import stack.
@@ -181,7 +177,7 @@ public class ProjectHelper {
         return extensionStack;
     }
 
-    private static final ThreadLocal<String> targetPrefix = new ThreadLocal<String>();
+    private static final ThreadLocal<String> targetPrefix = new ThreadLocal<>();
 
     /**
      * The prefix to prepend to imported target names.
@@ -199,23 +195,21 @@ public class ProjectHelper {
     /**
      * Sets the prefix to prepend to imported target names.
      *
+     * @param prefix String
      * @since Ant 1.8.0
      */
     public static void setCurrentTargetPrefix(String prefix) {
         targetPrefix.set(prefix);
     }
 
-    private static final ThreadLocal<String> prefixSeparator = new ThreadLocal<String>() {
-            protected String initialValue() {
-                return ".";
-            }
-        };
+    private static final ThreadLocal<String> prefixSeparator = ThreadLocal.withInitial(() -> ".");
 
     /**
      * The separator between the prefix and the target name.
      *
      * <p>May be set by &lt;import&gt;'s prefixSeparator attribute.</p>
      *
+     * @return String
      * @since Ant 1.8.0
      */
     public static String getCurrentPrefixSeparator() {
@@ -225,17 +219,14 @@ public class ProjectHelper {
     /**
      * Sets the separator between the prefix and the target name.
      *
+     * @param sep String
      * @since Ant 1.8.0
      */
     public static void setCurrentPrefixSeparator(String sep) {
         prefixSeparator.set(sep);
     }
 
-    private static final ThreadLocal<Boolean> inIncludeMode = new ThreadLocal<Boolean>() {
-            protected Boolean initialValue() {
-                return Boolean.FALSE;
-            }
-        };
+    private static final ThreadLocal<Boolean> inIncludeMode = ThreadLocal.withInitial(() -> Boolean.FALSE);
 
     /**
      * Whether the current file should be read in include as opposed
@@ -250,6 +241,7 @@ public class ProjectHelper {
      * overwritten in the importing build file.  The depends list of
      * the imported targets is not modified at all.</p>
      *
+     * @return boolean
      * @since Ant 1.8.0
      */
     public static boolean isInIncludeMode() {
@@ -260,10 +252,11 @@ public class ProjectHelper {
      * Sets whether the current file should be read in include as
      * opposed to import mode.
      *
+     * @param includeMode boolean
      * @since Ant 1.8.0
      */
     public static void setInIncludeMode(boolean includeMode) {
-        inIncludeMode.set(Boolean.valueOf(includeMode));
+        inIncludeMode.set(includeMode);
     }
 
     // --------------------  Parse method  --------------------
@@ -292,7 +285,7 @@ public class ProjectHelper {
      * @see org.apache.tools.ant.ProjectHelperRepository#getHelpers()
      */
     public static ProjectHelper getProjectHelper() {
-        return (ProjectHelper) ProjectHelperRepository.getInstance().getHelpers().next();
+        return ProjectHelperRepository.getInstance().getHelpers().next();
     }
 
     /**
@@ -304,6 +297,7 @@ public class ProjectHelper {
      * @return the current context class loader, or <code>null</code>
      * if the context class loader is unavailable.
      */
+    @Deprecated
     public static ClassLoader getContextClassLoader() {
         return LoaderUtils.isContextLoaderAvailable() ? LoaderUtils.getContextClassLoader() : null;
     }
@@ -326,6 +320,7 @@ public class ProjectHelper {
      * @exception BuildException if any of the attributes can't be handled by
      *                           the target
      */
+    @Deprecated
     public static void configure(Object target, AttributeList attrs,
                                  Project project) throws BuildException {
         if (target instanceof TypeAdapter) {
@@ -429,6 +424,7 @@ public class ProjectHelper {
      *             Use project.replaceProperties().
      * @since 1.5
      */
+    @Deprecated
      public static String replaceProperties(Project project, String value) throws BuildException {
         // needed since project properties are not accessible
          return project.replaceProperties(value);
@@ -454,6 +450,7 @@ public class ProjectHelper {
      * @deprecated since 1.6.x.
      *             Use PropertyHelper.
      */
+    @Deprecated
      public static String replaceProperties(Project project, String value, Hashtable<String, Object> keys)
              throws BuildException {
         PropertyHelper ph = PropertyHelper.getPropertyHelper(project);
@@ -481,6 +478,7 @@ public class ProjectHelper {
      * @exception BuildException if the string contains an opening
      *                           <code>${</code> without a closing <code>}</code>
      */
+    @Deprecated
     public static void parsePropertyString(String value, Vector<String> fragments, Vector<String> propertyRefs)
             throws BuildException {
         PropertyHelper.parsePropertyStringDefault(value, fragments, propertyRefs);
@@ -496,7 +494,7 @@ public class ProjectHelper {
      * @return      The stringified form of the ns name
      */
     public static String genComponentName(String uri, String name) {
-        if (uri == null || uri.equals("") || uri.equals(ANT_CORE_URI)) {
+        if (uri == null || uri.isEmpty() || uri.equals(ANT_CORE_URI)) {
             return name;
         }
         return uri + ":" + name;
@@ -558,10 +556,8 @@ public class ProjectHelper {
             return ex;
         }
         String errorMessage
-            = "The following error occurred while executing this line:"
-            + System.getProperty("line.separator")
-            + ex.getLocation().toString()
-            + ex.getMessage();
+            = String.format("The following error occurred while executing this line:%n%s%s",
+                ex.getLocation().toString(), ex.getMessage());
         if (ex instanceof ExitStatusException) {
             int exitStatus = ((ExitStatusException) ex).getStatus();
             if (newLocation == null) {
@@ -591,6 +587,8 @@ public class ProjectHelper {
      *
      * <p>This implementation returns false.</p>
      *
+     * @param r Resource
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean canParseAntlibDescriptor(Resource r) {
@@ -601,6 +599,9 @@ public class ProjectHelper {
      * Parse the given URL as an antlib descriptor and return the
      * content as something that can be turned into an Antlib task.
      *
+     * @param containingProject Project
+     * @param source Resource
+     * @return UnknownElement
      * @since ant 1.8.0
      */
     public UnknownElement parseAntlibDescriptor(Project containingProject,
