@@ -18,13 +18,14 @@
 package org.apache.tools.ant.helper;
 
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
+import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
+import java.nio.file.Files;
 import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.Map;
@@ -88,6 +89,7 @@ public class ProjectHelper2 extends ProjectHelper {
      *
      * @since Ant 1.8.0
      */
+    @Override
     public boolean canParseAntlibDescriptor(Resource resource) {
         return true;
     }
@@ -102,6 +104,7 @@ public class ProjectHelper2 extends ProjectHelper {
      *
      * @since Ant 1.8.0
      */
+    @Override
     public UnknownElement parseAntlibDescriptor(Project containingProject,
                                                 Resource resource) {
         URLProvider up = resource.as(URLProvider.class);
@@ -143,10 +146,11 @@ public class ProjectHelper2 extends ProjectHelper {
      * @param source  the xml source
      * @exception BuildException if an error occurs
      */
+    @Override
     public void parse(Project project, Object source) throws BuildException {
         getImportStack().addElement(source);
         AntXMLContext context = null;
-        context = (AntXMLContext) project.getReference(REFID_CONTEXT);
+        context = project.getReference(REFID_CONTEXT);
         if (context == null) {
             context = new AntXMLContext(project);
             project.addReference(REFID_CONTEXT, context);
@@ -163,7 +167,7 @@ public class ProjectHelper2 extends ProjectHelper {
                 newCurrent.setProject(project);
                 newCurrent.setName("");
                 context.setCurrentTarget(newCurrent);
-                context.setCurrentTargets(new HashMap<String, Target>());
+                context.setCurrentTargets(new HashMap<>());
                 context.setImplicitTarget(newCurrent);
                 parse(project, source, new RootHandler(context, mainHandler));
                 newCurrent.execute();
@@ -174,7 +178,7 @@ public class ProjectHelper2 extends ProjectHelper {
             }
         } else {
             // top level file
-            context.setCurrentTargets(new HashMap<String, Target>());
+            context.setCurrentTargets(new HashMap<>());
             parse(project, source, new RootHandler(context, mainHandler));
             // Execute the top-level target
             context.getImplicitTarget().execute();
@@ -206,13 +210,11 @@ public class ProjectHelper2 extends ProjectHelper {
         } else if (source instanceof URL) {
             url = (URL) source;
         } else if (source instanceof Resource) {
-            FileProvider fp =
-                ((Resource) source).as(FileProvider.class);
+            FileProvider fp = ((Resource) source).as(FileProvider.class);
             if (fp != null) {
                 buildFile = fp.getFile();
             } else {
-                URLProvider up =
-                    ((Resource) source).as(URLProvider.class);
+                URLProvider up = ((Resource) source).as(URLProvider.class);
                 if (up != null) {
                     url = up.getURL();
                 }
@@ -226,7 +228,7 @@ public class ProjectHelper2 extends ProjectHelper {
             try {
                 context.setBuildFile((File) null);
                 context.setBuildFile(url);
-            } catch (java.net.MalformedURLException ex) {
+            } catch (MalformedURLException ex) {
                 throw new BuildException(ex);
             }
             buildFileName = url.toString();
@@ -247,16 +249,15 @@ public class ProjectHelper2 extends ProjectHelper {
             String uri = null;
             if (buildFile != null) {
                 uri = FILE_UTILS.toURI(buildFile.getAbsolutePath());
-                inputStream = new FileInputStream(buildFile);
+                inputStream = Files.newInputStream(buildFile.toPath());
             } else {
                 uri = url.toString();
-                int pling = -1;
-                if (uri.startsWith("jar:file")
-                    && (pling = uri.indexOf("!/")) > -1) {
+                int pling = uri.indexOf("!/");
+                if (uri.startsWith("jar:file") && pling > -1) {
                     zf = new ZipFile(org.apache.tools.ant.launch.Locator
                                      .fromJarURI(uri), "UTF-8");
                     inputStream =
-                        zf.getInputStream(zf.getEntry(uri.substring(pling + 1)));
+                        zf.getInputStream(zf.getEntry(uri.substring(pling + 2)));
                 } else {
                     URLConnection conn = url.openConnection();
                     conn.setUseCaches(false);
@@ -272,12 +273,10 @@ public class ProjectHelper2 extends ProjectHelper {
                         + uri + (zf != null ? " from a zip file" : ""),
                         Project.MSG_VERBOSE);
 
-            DefaultHandler hb = handler;
-
-            parser.setContentHandler(hb);
-            parser.setEntityResolver(hb);
-            parser.setErrorHandler(hb);
-            parser.setDTDHandler(hb);
+            parser.setContentHandler(handler);
+            parser.setEntityResolver(handler);
+            parser.setErrorHandler(handler);
+            parser.setDTDHandler(handler);
             parser.parse(inputSource);
         } catch (SAXParseException exc) {
             Location location = new Location(exc.getSystemId(), exc.getLineNumber(), exc
@@ -467,7 +466,7 @@ public class ProjectHelper2 extends ProjectHelper {
             throws SAXParseException {
             String s = new String(buf, start, count).trim();
 
-            if (s.length() > 0) {
+            if (!s.isEmpty()) {
                 throw new SAXParseException("Unexpected text \"" + s + "\"", context.getLocator());
             }
         }
@@ -483,11 +482,11 @@ public class ProjectHelper2 extends ProjectHelper {
 
     /**
      * Handler for ant processing. Uses a stack of AntHandlers to
-     * implement each element ( the original parser used a recursive behavior,
-     * with the implicit execution stack )
+     * implement each element (the original parser used a recursive behavior,
+     * with the implicit execution stack)
      */
     public static class RootHandler extends DefaultHandler {
-        private Stack<AntHandler> antHandlers = new Stack<AntHandler>();
+        private Stack<AntHandler> antHandlers = new Stack<>();
         private AntHandler currentHandler = null;
         private AntXMLContext context;
 
@@ -521,6 +520,7 @@ public class ProjectHelper2 extends ProjectHelper {
          *                 document. Will not be <code>null</code>.
          * @return an inputsource for this identifier
          */
+        @Override
         public InputSource resolveEntity(String publicId, String systemId) {
 
             context.getProject().log("resolving systemId: " + systemId, Project.MSG_VERBOSE);
@@ -538,10 +538,10 @@ public class ProjectHelper2 extends ProjectHelper {
                 }
                 context.getProject().log("file=" + file, Project.MSG_DEBUG);
                 try {
-                    InputSource inputSource = new InputSource(new FileInputStream(file));
+                    InputSource inputSource = new InputSource(Files.newInputStream(file.toPath()));
                     inputSource.setSystemId(FILE_UTILS.toURI(file.getAbsolutePath()));
                     return inputSource;
-                } catch (FileNotFoundException fne) {
+                } catch (IOException fne) {
                     context.getProject().log(file.getAbsolutePath() + " could not be found",
                                              Project.MSG_WARN);
                 }
@@ -566,6 +566,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @exception org.xml.sax.SAXParseException if the tag given is not
          *                              <code>"project"</code>
          */
+        @Override
         public void startElement(String uri, String tag, String qname, Attributes attrs)
             throws SAXParseException {
             AntHandler next = currentHandler.onStartChild(uri, tag, qname, attrs, context);
@@ -580,6 +581,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @param locator The locator used by the parser.
          *                Will not be <code>null</code>.
          */
+        @Override
         public void setDocumentLocator(Locator locator) {
             context.setLocator(locator);
         }
@@ -595,10 +597,10 @@ public class ProjectHelper2 extends ProjectHelper {
          *
          * @exception SAXException in case of error (not thrown in this implementation)
          */
+        @Override
         public void endElement(String uri, String name, String qName) throws SAXException {
             currentHandler.onEndElement(uri, name, context);
-            AntHandler prev = (AntHandler) antHandlers.pop();
-            currentHandler = prev;
+            currentHandler = antHandlers.pop();
             if (currentHandler != null) {
                 currentHandler.onEndChild(uri, name, qName, context);
             }
@@ -612,6 +614,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @param count The number of characters to read.
          * @exception SAXParseException if an error occurs
          */
+        @Override
         public void characters(char[] buf, int start, int count) throws SAXParseException {
             currentHandler.characters(buf, start, count, context);
         }
@@ -622,6 +625,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @param prefix the namespace prefix
          * @param uri the namespace uri
          */
+        @Override
         public void startPrefixMapping(String prefix, String uri) {
             context.startPrefixMapping(prefix, uri);
         }
@@ -631,6 +635,7 @@ public class ProjectHelper2 extends ProjectHelper {
          *
          * @param prefix the prefix that is not mapped anymore
          */
+        @Override
         public void endPrefixMapping(String prefix) {
             context.endPrefixMapping(prefix);
         }
@@ -654,10 +659,11 @@ public class ProjectHelper2 extends ProjectHelper {
          * @return The project handler that handles subelements of project
          * @exception SAXParseException if the qualified name is not "project".
          */
+        @Override
         public AntHandler onStartChild(String uri, String name, String qname, Attributes attrs,
                                        AntXMLContext context) throws SAXParseException {
-            if (name.equals("project")
-                && (uri.equals("") || uri.equals(ANT_CORE_URI))) {
+            if ("project".equals(name)
+                && (uri.isEmpty() || uri.equals(ANT_CORE_URI))) {
                 return ProjectHelper2.projectHandler;
             }
             if (name.equals(qname)) {
@@ -693,6 +699,7 @@ public class ProjectHelper2 extends ProjectHelper {
          *            encountered or if the <code>"default"</code> attribute
          *            is missing.
          */
+        @Override
         public void onStartElement(String uri, String tag, String qname, Attributes attrs,
                                    AntXMLContext context) throws SAXParseException {
             String baseDir = null;
@@ -706,61 +713,65 @@ public class ProjectHelper2 extends ProjectHelper {
              * too 'involved' in the processing. A better solution (IMO)
              * would be to create UE for Project and Target too, and
              * then process the tree and have Project/Target deal with
-             * its attributes ( similar with Description ).
+             * its attributes (similar with Description).
              *
-             * If we eventually switch to ( or add support for ) DOM,
+             * If we eventually switch to (or add support for) DOM,
              * things will work smoothly - UE can be avoided almost completely
-             * ( it could still be created on demand, for backward compatibility )
+             * (it could still be created on demand, for backward compatibility)
              */
 
             for (int i = 0; i < attrs.getLength(); i++) {
                 String attrUri = attrs.getURI(i);
-                if (attrUri != null && !attrUri.equals("") && !attrUri.equals(uri)) {
+                if (attrUri != null && !attrUri.isEmpty() && !attrUri.equals(uri)) {
                     continue; // Ignore attributes from unknown uris
                 }
-                String key = attrs.getLocalName(i);
                 String value = attrs.getValue(i);
-
-                if (key.equals("default")) {
-                    if (value != null && !value.equals("")) {
-                        if (!context.isIgnoringProjectTag()) {
-                            project.setDefault(value);
-                        }
-                    }
-                } else if (key.equals("name")) {
-                    if (value != null) {
-                        context.setCurrentProjectName(value);
-                        nameAttributeSet = true;
-                        if (!context.isIgnoringProjectTag()) {
-                            project.setName(value);
-                            project.addReference(value, project);
-                        } else if (isInIncludeMode()) {
-                            if (!"".equals(value) && getCurrentTargetPrefix()!= null && getCurrentTargetPrefix().endsWith(ProjectHelper.USE_PROJECT_NAME_AS_TARGET_PREFIX))  {
-                                String newTargetPrefix = getCurrentTargetPrefix().replace(ProjectHelper.USE_PROJECT_NAME_AS_TARGET_PREFIX, value);
-                                // help nested include tasks
-                                setCurrentTargetPrefix(newTargetPrefix);
+                switch (attrs.getLocalName(i)) {
+                    case "default":
+                        if (value != null && !value.isEmpty()) {
+                            if (!context.isIgnoringProjectTag()) {
+                                project.setDefault(value);
                             }
                         }
-                    }
-                } else if (key.equals("id")) {
-                    if (value != null) {
-                        // What's the difference between id and name ?
-                        if (!context.isIgnoringProjectTag()) {
-                            project.addReference(value, project);
+                        break;
+                    case "name":
+                        if (value != null) {
+                            context.setCurrentProjectName(value);
+                            nameAttributeSet = true;
+                            if (!context.isIgnoringProjectTag()) {
+                                project.setName(value);
+                                project.addReference(value, project);
+                            } else if (isInIncludeMode()) {
+                                if (!value.isEmpty() && getCurrentTargetPrefix() != null
+                                        && getCurrentTargetPrefix().endsWith(ProjectHelper.USE_PROJECT_NAME_AS_TARGET_PREFIX)) {
+                                    String newTargetPrefix = getCurrentTargetPrefix().replace(ProjectHelper.USE_PROJECT_NAME_AS_TARGET_PREFIX, value);
+                                    // help nested include tasks
+                                    setCurrentTargetPrefix(newTargetPrefix);
+                                }
+                            }
                         }
-                    }
-                } else if (key.equals("basedir")) {
-                    if (!context.isIgnoringProjectTag()) {
-                        baseDir = value;
-                    }
-                } else {
-                    // TODO ignore attributes in a different NS ( maybe store them ? )
-                    throw new SAXParseException("Unexpected attribute \"" + attrs.getQName(i)
-                                                + "\"", context.getLocator());
+                        break;
+                    case "id":
+                        if (value != null) {
+                            // What's the difference between id and name ?
+                            if (!context.isIgnoringProjectTag()) {
+                                project.addReference(value, project);
+                            }
+                        }
+                        break;
+                    case "basedir":
+                        if (!context.isIgnoringProjectTag()) {
+                            baseDir = value;
+                        }
+                        break;
+                    default:
+                        // TODO ignore attributes in a different NS (maybe store them ?)
+                        throw new SAXParseException("Unexpected attribute \"" + attrs.getQName(i)
+                                + "\"", context.getLocator());
                 }
             }
 
-            // TODO Move to Project ( so it is shared by all helpers )
+            // TODO Move to Project (so it is shared by all helpers)
             String antFileProp =
                 MagicNames.ANT_FILE + "." + context.getCurrentProjectName();
             String dup = project.getProperty(antFileProp);
@@ -773,7 +784,7 @@ public class ProjectHelper2 extends ProjectHelper {
                 if (MagicNames.ANT_FILE_TYPE_URL.equals(dupType)) {
                     try {
                         dupFile = new URL(dup);
-                    } catch (java.net.MalformedURLException mue) {
+                    } catch (MalformedURLException mue) {
                         throw new BuildException("failed to parse "
                                                  + dup + " as URL while looking"
                                                  + " at a duplicate project"
@@ -849,10 +860,11 @@ public class ProjectHelper2 extends ProjectHelper {
          *            <code>"extension-point"</code>
          *            or a data type definition
          */
+        @Override
         public AntHandler onStartChild(String uri, String name, String qname, Attributes attrs,
                                        AntXMLContext context) throws SAXParseException {
-            return (name.equals("target") || name.equals("extension-point"))
-                && (uri.equals("") || uri.equals(ANT_CORE_URI))
+            return ("target".equals(name) || "extension-point".equals(name))
+                && (uri.isEmpty() || uri.equals(ANT_CORE_URI))
                 ? ProjectHelper2.targetHandler : ProjectHelper2.elementHandler;
         }
     }
@@ -882,6 +894,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @exception SAXParseException if an unexpected attribute is encountered
          *            or if the <code>"name"</code> attribute is missing.
          */
+        @Override
         public void onStartElement(String uri, String tag, String qname, Attributes attrs,
                                    AntXMLContext context) throws SAXParseException {
             String name = null;
@@ -898,40 +911,47 @@ public class ProjectHelper2 extends ProjectHelper {
 
             for (int i = 0; i < attrs.getLength(); i++) {
                 String attrUri = attrs.getURI(i);
-                if (attrUri != null && !attrUri.equals("") && !attrUri.equals(uri)) {
+                if (attrUri != null && !attrUri.isEmpty() && !attrUri.equals(uri)) {
                     continue; // Ignore attributes from unknown uris
                 }
-                String key = attrs.getLocalName(i);
                 String value = attrs.getValue(i);
-
-                if (key.equals("name")) {
-                    name = value;
-                    if ("".equals(name)) {
-                        throw new BuildException("name attribute must " + "not be empty");
-                    }
-                } else if (key.equals("depends")) {
-                    depends = value;
-                } else if (key.equals("if")) {
-                    target.setIf(value);
-                } else if (key.equals("unless")) {
-                    target.setUnless(value);
-                } else if (key.equals("id")) {
-                    if (value != null && !value.equals("")) {
-                        context.getProject().addReference(value, target);
-                    }
-                } else if (key.equals("description")) {
-                    target.setDescription(value);
-                } else if (key.equals("extensionOf")) {
-                    extensionPoint = value;
-                } else if (key.equals("onMissingExtensionPoint")) {
-                    try {
-                        extensionPointMissing = OnMissingExtensionPoint.valueOf(value);
-                    } catch (IllegalArgumentException e) {
-                        throw new BuildException("Invalid onMissingExtensionPoint " + value);
-                    }
-                } else {
-                    throw new SAXParseException("Unexpected attribute \"" + key + "\"", context
-                                                .getLocator());
+                switch (attrs.getLocalName(i)) {
+                    case "name":
+                        name = value;
+                        if (name.isEmpty()) {
+                            throw new BuildException("name attribute must not be empty");
+                        }
+                        break;
+                    case "depends":
+                        depends = value;
+                        break;
+                    case "if":
+                        target.setIf(value);
+                        break;
+                    case "unless":
+                        target.setUnless(value);
+                        break;
+                    case "id":
+                        if (value != null && !value.isEmpty()) {
+                            context.getProject().addReference(value, target);
+                        }
+                        break;
+                    case "description":
+                        target.setDescription(value);
+                        break;
+                    case "extensionOf":
+                        extensionPoint = value;
+                        break;
+                    case "onMissingExtensionPoint":
+                        try {
+                            extensionPointMissing = OnMissingExtensionPoint.valueOf(value);
+                        } catch (IllegalArgumentException e) {
+                            throw new BuildException("Invalid onMissingExtensionPoint " + value);
+                        }
+                        break;
+                    default:
+                        throw new SAXParseException("Unexpected attribute \"" + attrs.getQName(i)
+                                + "\"", context.getLocator());
                 }
             }
 
@@ -963,7 +983,7 @@ public class ProjectHelper2 extends ProjectHelper {
                                          target.getLocation());
             }
             Hashtable<String, Target> projectTargets = project.getTargets();
-            boolean   usedTarget = false;
+            boolean usedTarget = false;
             // If the name has not already been defined define it
             if (projectTargets.containsKey(name)) {
                 project.log("Already defined in main or a previous import, ignore " + name,
@@ -975,7 +995,7 @@ public class ProjectHelper2 extends ProjectHelper {
                 usedTarget = true;
             }
 
-            if (depends.length() > 0) {
+            if (!depends.isEmpty()) {
                 if (!isInIncludeMode) {
                     target.setDepends(depends);
                 } else {
@@ -1006,8 +1026,7 @@ public class ProjectHelper2 extends ProjectHelper {
             }
             if (extensionPoint != null) {
                 ProjectHelper helper =
-                    (ProjectHelper) context.getProject().
-                    getReference(ProjectHelper.PROJECTHELPER_REFERENCE);
+                        context.getProject().getReference(ProjectHelper.PROJECTHELPER_REFERENCE);
                 for (String extPointName : Target.parseDepends(extensionPoint, name, "extensionOf")) {
                     if (extensionPointMissing == null) {
                         extensionPointMissing = OnMissingExtensionPoint.FAIL;
@@ -1032,7 +1051,7 @@ public class ProjectHelper2 extends ProjectHelper {
 
         private String getTargetPrefix(AntXMLContext context) {
             String configuredValue = getCurrentTargetPrefix();
-            if (configuredValue != null && configuredValue.length() == 0) {
+            if (configuredValue != null && configuredValue.isEmpty()) {
                 configuredValue = null;
             }
             if (configuredValue != null) {
@@ -1040,7 +1059,7 @@ public class ProjectHelper2 extends ProjectHelper {
             }
 
             String projectName = context.getCurrentProjectName();
-            if ("".equals(projectName)) {
+            if (projectName != null && projectName.isEmpty()) {
                 projectName = null;
             }
 
@@ -1062,6 +1081,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @exception SAXParseException if an error occurs when initialising
          *                              the appropriate child handler
          */
+        @Override
         public AntHandler onStartChild(String uri, String name, String qname, Attributes attrs,
                                        AntXMLContext context) throws SAXParseException {
             return ProjectHelper2.elementHandler;
@@ -1075,13 +1095,14 @@ public class ProjectHelper2 extends ProjectHelper {
          * @param tag The name of the element.
          * @param context The current context.
          */
+        @Override
         public void onEndElement(String uri, String tag, AntXMLContext context) {
             context.setCurrentTarget(context.getImplicitTarget());
         }
     }
 
     /**
-     * Handler for all project elements ( tasks, data types )
+     * Handler for all project elements (tasks, data types)
      */
     public static class ElementHandler extends AntHandler {
 
@@ -1109,6 +1130,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @exception SAXParseException in case of error (not thrown in
          *                              this implementation)
          */
+        @Override
         public void onStartElement(String uri, String tag, String qname, Attributes attrs,
                                    AntXMLContext context) throws SAXParseException {
             RuntimeConfigurable parentWrapper = context.currentWrapper();
@@ -1136,7 +1158,7 @@ public class ProjectHelper2 extends ProjectHelper {
                 // Nested element
                 ((UnknownElement) parent).addChild(task);
             }  else {
-                // Task included in a target ( including the default one ).
+                // Task included in a target (including the default one).
                 context.getCurrentTarget().addTask(task);
             }
 
@@ -1150,7 +1172,7 @@ public class ProjectHelper2 extends ProjectHelper {
             for (int i = 0; i < attrs.getLength(); i++) {
                 String name = attrs.getLocalName(i);
                 String attrUri = attrs.getURI(i);
-                if (attrUri != null && !attrUri.equals("") && !attrUri.equals(uri)) {
+                if (attrUri != null && !attrUri.isEmpty() && !attrUri.equals(uri)) {
                     name = attrUri + ":" + attrs.getQName(i);
                 }
                 String value = attrs.getValue(i);
@@ -1195,6 +1217,7 @@ public class ProjectHelper2 extends ProjectHelper {
          *
          * @see ProjectHelper#addText(Project,java.lang.Object,char[],int,int)
          */
+        @Override
         public void characters(char[] buf, int start, int count,
                                AntXMLContext context) throws SAXParseException {
             RuntimeConfigurable wrapper = context.currentWrapper();
@@ -1218,6 +1241,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @exception SAXParseException if an error occurs when initialising
          *                              the appropriate child handler
          */
+        @Override
         public AntHandler onStartChild(String uri, String tag, String qname, Attributes attrs,
                                        AntXMLContext context) throws SAXParseException {
             return ProjectHelper2.elementHandler;
@@ -1231,6 +1255,7 @@ public class ProjectHelper2 extends ProjectHelper {
          * @param tag The name of the element.
          * @param context The current context.
          */
+        @Override
         public void onEndElement(String uri, String tag, AntXMLContext context) {
             context.popWrapper();
         }
