@@ -183,9 +183,9 @@ public class LoadProperties extends Task {
 
             String text = instream.readFully();
 
-            if (!(text == null || text.isEmpty())) {
+            if (text != null && !text.isEmpty()) {
                 if (!text.endsWith("\n")) {
-                    text = text + "\n";
+                    text += "\n";
                 }
                 ByteArrayInputStream tis = new ByteArrayInputStream(
                     text.getBytes(ResourceUtils.ISO_8859_1));
