@@ -18,7 +18,6 @@
 package org.apache.tools.ant.taskdefs;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.apache.tools.ant.BuildException;
@@ -33,7 +32,7 @@ import org.apache.tools.ant.Task;
  */
 public class ProjectHelperTask extends Task {
 
-    private List projectHelpers = new ArrayList();
+    private List<ProjectHelper> projectHelpers = new ArrayList<>();
 
     public synchronized void addConfigured(ProjectHelper projectHelper) {
         this.projectHelpers.add(projectHelper);
@@ -41,10 +40,7 @@ public class ProjectHelperTask extends Task {
 
     @Override
     public void execute() throws BuildException {
-        ProjectHelperRepository repo = ProjectHelperRepository.getInstance();
-        for (Iterator it = projectHelpers.iterator(); it.hasNext();) {
-            ProjectHelper helper = (ProjectHelper) it.next();
-            repo.registerProjectHelper(helper.getClass());
-        }
+        projectHelpers.stream().map(ProjectHelper::getClass).forEach(
+            ProjectHelperRepository.getInstance()::registerProjectHelper);
     }
 }
