@@ -99,13 +99,13 @@ public class VmsCommandLauncher extends Java13CommandLauncher {
             // add the environment as logicals to the DCL script
             if (env != null) {
                 int eqIndex;
-                for (int i = 0; i < env.length; i++) {
-                    eqIndex = env[i].indexOf('=');
+                for (String variable : env) {
+                    eqIndex = variable.indexOf('=');
                     if (eqIndex != -1) {
                         out.write("$ DEFINE/NOLOG ");
-                        out.write(env[i].substring(0, eqIndex));
+                        out.write(variable.substring(0, eqIndex));
                         out.write(" \"");
-                        out.write(env[i].substring(eqIndex + 1));
+                        out.write(variable.substring(eqIndex + 1));
                         out.write('\"');
                         out.newLine();
                     }
@@ -122,16 +122,13 @@ public class VmsCommandLauncher extends Java13CommandLauncher {
     }
 
     private void deleteAfter(final File f, final Process p) {
-        new Thread() {
-            @Override
-            public void run() {
-                try {
-                    p.waitFor();
-                } catch(InterruptedException e) {
-                    // ignore
-                }
-                FileUtils.delete(f);
+        new Thread(() -> {
+            try {
+                p.waitFor();
+            } catch (InterruptedException e) {
+                // ignore
             }
-        }.start();
+            FileUtils.delete(f);
+        }).start();
     }
 }
