@@ -74,7 +74,7 @@ public class XMLValidateTask extends Task {
     /** file to be validated */
     protected File file = null;
     /** sets of file to be validated */
-    protected Vector filesets = new Vector();
+    protected Vector<FileSet> filesets = new Vector<>();
     protected Path classpath;
 
     /**
@@ -90,12 +90,12 @@ public class XMLValidateTask extends Task {
     // CheckStyle:VisibilityModifier ON
 
     /** The vector to store all attributes (features) to be set on the parser. **/
-    private Vector attributeList = new Vector();
+    private Vector<Attribute> attributeList = new Vector<>();
 
     /**
      * List of properties.
      */
-    private final Vector propertyList = new Vector();
+    private final Vector<Property> propertyList = new Vector<>();
 
     private XMLCatalog xmlCatalog = new XMLCatalog();
     /** Message for successful validation */
@@ -288,7 +288,7 @@ public class XMLValidateTask extends Task {
     public void execute() throws BuildException {
         try {
             int fileProcessed = 0;
-            if (file == null && (filesets.isEmpty())) {
+            if (file == null && filesets.isEmpty()) {
                 throw new BuildException(
                     "Specify at least one source - " + "a file or a fileset.");
             }
@@ -307,15 +307,10 @@ public class XMLValidateTask extends Task {
                 }
             }
 
-            final int size = filesets.size();
-            for (int i = 0; i < size; i++) {
-
-                FileSet fs = (FileSet) filesets.elementAt(i);
+            for (final FileSet fs : filesets) {
                 DirectoryScanner ds = fs.getDirectoryScanner(getProject());
-                String[] files = ds.getIncludedFiles();
-
-                for (int j = 0; j < files.length; j++) {
-                    File srcFile = new File(fs.getDir(getProject()), files[j]);
+                for (String fileName : ds.getIncludedFiles()) {
+                    File srcFile = new File(fs.getDir(getProject()), fileName);
                     doValidate(srcFile);
                     fileProcessed++;
                 }
@@ -353,16 +348,12 @@ public class XMLValidateTask extends Task {
                 setFeature(XmlConstants.FEATURE_VALIDATION, true);
             }
             // set the feature from the attribute list
-            final int attSize = attributeList.size();
-            for (int i = 0; i < attSize; i++) {
-                Attribute feature = (Attribute) attributeList.elementAt(i);
+            for (final Attribute feature : attributeList) {
                 setFeature(feature.getName(), feature.getValue());
 
             }
             // Sets properties
-            final int propSize = propertyList.size();
-            for (int i = 0; i < propSize; i++) {
-                final Property prop = (Property) propertyList.elementAt(i);
+            for (final Property prop : propertyList) {
                 setProperty(prop.getName(), prop.getValue());
             }
         }
@@ -390,7 +381,7 @@ public class XMLValidateTask extends Task {
             reader = createDefaultReaderOrParser();
         } else {
 
-            Class readerClass = null;
+            Class<?> readerClass = null;
             try {
                 // load the parser class
                 if (classpath != null) {
@@ -402,11 +393,7 @@ public class XMLValidateTask extends Task {
                 }
 
                 reader = readerClass.newInstance();
-            } catch (ClassNotFoundException e) {
-                throw new BuildException(INIT_FAILED_MSG + readerClassName, e);
-            } catch (InstantiationException e) {
-                throw new BuildException(INIT_FAILED_MSG + readerClassName, e);
-            } catch (IllegalAccessException e) {
+            } catch (ClassNotFoundException | IllegalAccessException | InstantiationException e) {
                 throw new BuildException(INIT_FAILED_MSG + readerClassName, e);
             }
         }
@@ -654,7 +641,7 @@ public class XMLValidateTask extends Task {
                 }
                 int line = e.getLineNumber();
                 int col = e.getColumnNumber();
-                return  name
+                return name
                     + (line == -1
                        ? ""
                        : (":" + line + (col == -1 ? "" : (":" + col))))
@@ -670,11 +657,10 @@ public class XMLValidateTask extends Task {
      * @since ant1.6
      */
     public static class Attribute {
-        /** The name of the attribute to set.
+        /**
+         * The name of the attribute to set.
          *
-         * Valid attributes <a href=
-         * "http://www.saxproject.org/apidoc/org/xml/sax/package-summary.html#package_description"
-         * >include.</a>
+         * Valid attributes <a href="http://www.saxproject.org/apidoc/org/xml/sax/package-summary.html#package_description">include</a>
          */
         private String attributeName = null;
 
