@@ -225,8 +225,7 @@ public class Image extends MatchingTask {
                           final File dstDir, final FileNameMapper mapper) {
         int writeCount = 0;
 
-        for (int i = 0; i < srcNames.length; ++i) {
-            final String srcName = srcNames[i];
+        for (final String srcName : srcNames) {
             final File srcFile = new File(srcDir, srcName).getAbsoluteFile();
 
             final String[] dstNames = mapper.mapFileName(srcName);
@@ -241,7 +240,7 @@ public class Image extends MatchingTask {
 
                 if (dstFile.exists()) {
                     // avoid overwriting unless necessary
-                    if(!overwrite
+                    if (!overwrite
                        && srcFile.lastModified() <= dstFile.lastModified()) {
 
                         log(srcFile + " omitted as " + dstFile
