@@ -18,7 +18,6 @@
 
 package org.apache.tools.ant.taskdefs.optional.junit;
 
-import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.Properties;
 import java.util.Vector;
@@ -28,10 +27,10 @@ import org.apache.tools.ant.Project;
 import org.apache.tools.ant.PropertyHelper;
 
 /**
- * <p> Run a single JUnit test.
+ * Run a single JUnit test.
  *
- * <p> The JUnit test is actually run by {@link JUnitTestRunner}.
- * So read the doc comments for that class :)
+ * <p>The JUnit test is actually run by {@link JUnitTestRunner}.
+ * So read the doc comments for that class :)</p>
  *
  * @since Ant 1.2
  *
@@ -130,7 +129,7 @@ public class JUnitTest extends BaseTest implements Cloneable {
         this.haltOnFail = haltOnFailure;
         this.filtertrace = filtertrace;
         this.methodsSpecified = methods != null;
-        this.methods = methodsSpecified ? (String[]) methods.clone() : null;
+        this.methods = methodsSpecified ? methods.clone() : null;
         this.antThreadID = thread;
     }
 
@@ -222,13 +221,13 @@ public class JUnitTest extends BaseTest implements Cloneable {
      * @since 1.8.2
      */
     String getMethodsString() {
-        if ((methodsList == null) && methodsSpecified) {
+        if (methodsList == null && methodsSpecified) {
             if (methods.length == 0) {
                 methodsList = "";
             } else if (methods.length == 1) {
                 methodsList = methods[0];
             } else {
-                StringBuffer buf = new StringBuffer(methods.length * 16);
+                StringBuilder buf = new StringBuilder(methods.length * 16);
                 buf.append(methods[0]);
                 for (int i = 1; i < methods.length; i++) {
                     buf.append(',').append(methods[i]);
@@ -247,7 +246,7 @@ public class JUnitTest extends BaseTest implements Cloneable {
      * @since 1.8.2
      */
     void resolveMethods() {
-        if ((methods == null) && methodsSpecified) {
+        if (methods == null && methodsSpecified) {
             try {
                 methods = parseTestMethodNamesList(methodsList);
             } catch (IllegalArgumentException ex) {
@@ -482,12 +481,9 @@ public class JUnitTest extends BaseTest implements Cloneable {
      * @param p the properties.
      *          This is a copy of the projects ant properties.
      */
-    public void setProperties(Hashtable p) {
+    public void setProperties(Hashtable<?, ?> p) {
         props = new Properties();
-        for (Enumeration e = p.keys(); e.hasMoreElements();) {
-            Object key = e.nextElement();
-            props.put(key, p.get(key));
-        }
+        p.forEach(props::put);
     }
 
     /**
@@ -516,7 +512,7 @@ public class JUnitTest extends BaseTest implements Cloneable {
     /**
      * Convenient method to add formatters to a vector
      */
-    void addFormattersTo(Vector v) {
+    void addFormattersTo(Vector<? super FormatterElement> v) {
         final int count = formatters.size();
         for (int i = 0; i < count; i++) {
             v.addElement(formatters.elementAt(i));
@@ -527,12 +523,13 @@ public class JUnitTest extends BaseTest implements Cloneable {
      * @since Ant 1.5
      * @return a clone of this test.
      */
+    @SuppressWarnings("unchecked")
     @Override
     public Object clone() {
         try {
             JUnitTest t = (JUnitTest) super.clone();
             t.props = props == null ? null : (Properties) props.clone();
-            t.formatters = (Vector) formatters.clone();
+            t.formatters = (Vector<FormatterElement>) formatters.clone();
             return t;
         } catch (CloneNotSupportedException e) {
             // plain impossible
