@@ -42,7 +42,6 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.xml.sax.SAXException;
 
-
 /**
  * Aggregates all &lt;junit&gt; XML formatter testsuite data under
  * a specific directory and transforms the results via XSLT.
@@ -185,10 +184,8 @@ public class XMLResultAggregator extends Task implements XMLConstants {
             DirectoryScanner ds = fs.getDirectoryScanner(p);
             ds.scan();
             return Stream.of(ds.getIncludedFiles())
-                .filter(pathname -> pathname.endsWith(".xml")).map(pathname -> {
-                    return p.resolveFile(
-                        new File(ds.getBasedir(), pathname).getPath());
-                });
+                .filter(pathname -> pathname.endsWith(".xml"))
+                    .map(pathname -> p.resolveFile(new File(ds.getBasedir(), pathname).getPath()));
         }).toArray(File[]::new);
     }
 
@@ -230,14 +227,12 @@ public class XMLResultAggregator extends Task implements XMLConstants {
         generatedId = 0;
 
         // get all files and add them to the document
-        File[] files = getFiles();
-        for (int i = 0; i < files.length; i++) {
-            File file = files[i];
+        for (File file : getFiles()) {
             try {
                 log("Parsing file: '" + file + "'", Project.MSG_VERBOSE);
                 if (file.length() > 0) {
                     Document testsuiteDoc = builder.parse(FileUtils
-                        .getFileUtils().toURI(files[i].getAbsolutePath()));
+                            .getFileUtils().toURI(file.getAbsolutePath()));
                     Element elem = testsuiteDoc.getDocumentElement();
                     // make sure that this is REALLY a testsuite.
                     if (TESTSUITE.equals(elem.getNodeName())) {
