@@ -22,6 +22,7 @@ import java.io.File;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.LinkedHashSet;
+import java.util.List;
 import java.util.Set;
 import java.util.StringTokenizer;
 
@@ -31,8 +32,8 @@ import java.util.StringTokenizer;
 public class Directory {
 
     private File directory;
-    private Set childDirectories;
-    private ArrayList files;
+    private Set<Directory> childDirectories;
+    private List<File> files;
     private Directory parent;
 
     /**
@@ -48,10 +49,10 @@ public class Directory {
      * @param directory a directory
      * @param parent    a parent Directory
      */
-    public Directory(File directory , Directory parent) {
+    public Directory(File directory, Directory parent) {
         this.parent = parent;
-        this.childDirectories = new LinkedHashSet();
-        this.files = new ArrayList();
+        this.childDirectories = new LinkedHashSet<>();
+        this.files = new ArrayList<>();
         this.directory = directory;
     }
 
@@ -60,9 +61,7 @@ public class Directory {
      * @param directory a Directory
      */
     public void addDirectory(Directory directory) {
-        if (!childDirectories.contains(directory)) {
-            childDirectories.add(directory);
-        }
+        childDirectories.add(directory);
     }
 
     /**
@@ -77,7 +76,7 @@ public class Directory {
      * Get an iterator over the child Directories.
      * @return an iterator
      */
-    public Iterator directoryIterator() {
+    public Iterator<Directory> directoryIterator() {
         return childDirectories.iterator();
     }
 
@@ -85,7 +84,7 @@ public class Directory {
      * Get an iterator over the files.
      * @return an iterator
      */
-    public Iterator filesIterator() {
+    public Iterator<File> filesIterator() {
         return files.iterator();
     }
 
@@ -119,8 +118,7 @@ public class Directory {
      * @return the child directory, or null if not found
      */
     public Directory getChild(File dir) {
-        for (Iterator i = childDirectories.iterator(); i.hasNext();) {
-            Directory current = (Directory) i.next();
+        for (Directory current : childDirectories) {
             if (current.getDirectory().equals(dir)) {
                 return current;
             }
@@ -140,13 +138,12 @@ public class Directory {
             return true;
         }
 
-        if (!(obj instanceof Directory)) {
-            return false;
+        if (obj instanceof Directory) {
+            Directory d = (Directory) obj;
+            return this.directory.equals(d.directory);
         }
 
-        Directory d = (Directory) obj;
-
-        return this.directory.equals(d.directory);
+        return false;
     }
 
     /**
@@ -175,7 +172,7 @@ public class Directory {
     public static String[] getPath(String thePath) {
         StringTokenizer tokenizer = new StringTokenizer(thePath,
                 File.separator);
-        String[] path = new String[ tokenizer.countTokens() ];
+        String[] path = new String[tokenizer.countTokens()];
 
         int i = 0;
         while (tokenizer.hasMoreTokens()) {
