@@ -18,7 +18,6 @@
 
 package org.apache.tools.ant.taskdefs.optional.vss;
 
-import org.apache.tools.ant.types.EnumeratedAttribute;
 import java.io.File;
 import java.io.IOException;
 import java.text.DateFormat;
@@ -33,6 +32,7 @@ import org.apache.tools.ant.Task;
 import org.apache.tools.ant.taskdefs.Execute;
 import org.apache.tools.ant.taskdefs.LogStreamHandler;
 import org.apache.tools.ant.types.Commandline;
+import org.apache.tools.ant.types.EnumeratedAttribute;
 import org.apache.tools.ant.util.FileUtils;
 
 /**
@@ -95,15 +95,15 @@ public abstract class MSVSS extends Task implements MSVSSConstants {
     private int numDays = Integer.MIN_VALUE;
     /**  Date format for History */
     private DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.SHORT);
-    /**  Timestamp for retreived files */
+    /**  Timestamp for retrieved files */
     private CurrentModUpdated timestamp = null;
     /**  Behaviour for writable files */
     private WritableFiles writableFiles = null;
 
     /**
-     * Each sub-class must implemnt this method and return the constructed
+     * Each sub-class must implement this method and return the constructed
      * command line to be executed. It is up to the sub-task to determine the
-     * required attrubutes and their order.
+     * required attributes and their order.
      * @return    The Constructed command line.
      */
     abstract Commandline buildCmdLine();
@@ -170,15 +170,17 @@ public abstract class MSVSS extends Task implements MSVSSConstants {
     }
 
     /**
-     * Executes the task. <br>
+     * Executes the task.
+     * <p>
      * Builds a command line to execute ss.exe and then calls Exec's run method
      * to execute the command line.
+     * </p>
+     *
      * @throws BuildException if the command cannot execute.
      */
     public void execute() throws BuildException {
-        int result = 0;
         Commandline commandLine = buildCmdLine();
-        result = run(commandLine);
+        int result = run(commandLine);
         if (Execute.isFailure(result) && getFailOnError()) {
             String msg = "Failed executing: " + formatCommandLine(commandLine)
                      + " With a return code of " + result;
@@ -415,7 +417,7 @@ public abstract class MSVSS extends Task implements MSVSSConstants {
      */
     protected String getLabel() {
         String shortLabel = "";
-        if (label != null && label.length() > 0) {
+        if (label != null && !label.isEmpty()) {
                 shortLabel = FLAG_LABEL + getShortLabel();
         }
         return shortLabel;
@@ -461,7 +463,7 @@ public abstract class MSVSS extends Task implements MSVSSConstants {
             // Use getShortLabel() so labels longer then 30 char are truncated
             // and the user is warned
             String shortLabel = getShortLabel();
-            if (shortLabel != null && !shortLabel.equals("")) {
+            if (shortLabel != null && !shortLabel.isEmpty()) {
                 versionDateLabel = FLAG_VERSION_LABEL + shortLabel;
             }
         }
@@ -487,7 +489,7 @@ public abstract class MSVSS extends Task implements MSVSSConstants {
             //make sure m_LocalDir exists, create it if it doesn't
             File dir = getProject().resolveFile(localPath);
             if (!dir.exists()) {
-                boolean done = dir.mkdirs();
+                boolean done = dir.mkdirs() || dir.exists();
                 if (!done) {
                     String msg = "Directory " + localPath + " creation was not "
                             + "successful for an unknown reason";
@@ -637,7 +639,7 @@ public abstract class MSVSS extends Task implements MSVSSConstants {
      * @return    True if the FailOnError flag has been set or if 'writablefiles=skip'.
      */
     private boolean getFailOnError() {
-        return getWritableFiles().equals(WRITABLE_SKIP) ? false : failOnError;
+        return !getWritableFiles().equals(WRITABLE_SKIP) && failOnError;
     }
 
 
