@@ -48,7 +48,7 @@ public class KaffeRmic extends DefaultRmicAdapter {
      */
     @Override
     protected boolean areIiopAndIdlSupported() {
-        // actually I don't think Kaffee supports either, but we've
+        // actually I don't think Kaffe supports either, but we've
         // accepted the flags prior to 1.10.3
         return true;
     }
@@ -63,12 +63,12 @@ public class KaffeRmic extends DefaultRmicAdapter {
         if (c == null) {
             StringBuilder buf = new StringBuilder(
                 "Cannot use Kaffe rmic, as it is not available.  None of ");
-            for (int i = 0; i < RMIC_CLASSNAMES.length; i++) {
-                if (i != 0) {
+            for (String className : RMIC_CLASSNAMES) {
+                if (buf.length() > 0) {
                     buf.append(", ");
                 }
 
-                buf.append(RMIC_CLASSNAMES[i]);
+                buf.append(className);
             }
             buf.append(
                 " have been found. A common solution is to set the environment variable JAVA_HOME or CLASSPATH.");
@@ -102,9 +102,9 @@ public class KaffeRmic extends DefaultRmicAdapter {
      * @return null if neither class can get loaded.
      */
     private static Class<?> getRmicClass() {
-        for (int i = 0; i < RMIC_CLASSNAMES.length; i++) {
+        for (String className : RMIC_CLASSNAMES) {
             try {
-                return Class.forName(RMIC_CLASSNAMES[i]);
+                return Class.forName(className);
             } catch (ClassNotFoundException cnfe) {
                 // Ignore
             }
