@@ -21,6 +21,7 @@ package org.apache.tools.ant.types;
 import java.io.File;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
@@ -330,17 +331,16 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
      * @param tryUserDir  if true try the user directory if the file is not present
      */
     public void addExisting(Path source, boolean tryUserDir) {
-        String[] list = source.list();
         File userDir = (tryUserDir) ? new File(System.getProperty("user.dir"))
                 : null;
 
-        for (int i = 0; i < list.length; i++) {
-            File f = resolveFile(getProject(), list[i]);
+        for (String name : source.list()) {
+            File f = resolveFile(getProject(), name);
 
             // probably not the best choice, but it solves the problem of
             // relative paths in CLASSPATH
             if (tryUserDir && !f.exists()) {
-                f = new File(userDir, list[i]);
+                f = new File(userDir, name);
             }
             if (f.exists()) {
                 setLocation(f);
@@ -608,7 +608,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
             addExisting(systemBootClasspath);
         }
 
-        if (System.getProperty("java.vendor").toLowerCase(Locale.ENGLISH).indexOf("microsoft") >= 0) {
+        if (System.getProperty("java.vendor").toLowerCase(Locale.ENGLISH).contains("microsoft")) {
             // TODO is this code still necessary? is there any 1.2+ port?
             // Pull in *.zip from packages directory
             FileSet msZipFiles = new FileSet();
@@ -631,28 +631,25 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
                                  + File.separator + "rt.jar"));
 
             // Sun's and Apple's 1.4 have JCE and JSSE in separate jars.
-            String[] secJars = {"jce", "jsse"};
-            for (int i = 0; i < secJars.length; i++) {
+            for (String secJar : Arrays.asList("jce", "jsse")) {
                 addExisting(new Path(null,
-                                     System.getProperty("java.home")
-                                     + File.separator + "lib"
-                                     + File.separator + secJars[i] + ".jar"));
+                        System.getProperty("java.home")
+                                + File.separator + "lib"
+                                + File.separator + secJar + ".jar"));
                 addExisting(new Path(null,
-                                     System.getProperty("java.home")
-                                     + File.separator + ".."
-                                     + File.separator + "Classes"
-                                     + File.separator + secJars[i] + ".jar"));
+                        System.getProperty("java.home")
+                                + File.separator + ".."
+                                + File.separator + "Classes"
+                                + File.separator + secJar + ".jar"));
             }
 
             // IBM's 1.4 has rt.jar split into 4 smaller jars and a combined
             // JCE/JSSE in security.jar.
-            String[] ibmJars
-                = {"core", "graphics", "security", "server", "xml"};
-            for (int i = 0; i < ibmJars.length; i++) {
+            for (String ibmJar : Arrays.asList("core", "graphics", "security", "server", "xml")) {
                 addExisting(new Path(null,
-                                     System.getProperty("java.home")
-                                     + File.separator + "lib"
-                                     + File.separator + ibmJars[i] + ".jar"));
+                        System.getProperty("java.home")
+                                + File.separator + "lib"
+                                + File.separator + ibmJar + ".jar"));
             }
 
             // Added for MacOS X
@@ -686,9 +683,8 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
             }
         }
 
-        String[] dirs = extdirs.list();
-        for (int i = 0; i < dirs.length; i++) {
-            File dir = resolveFile(getProject(), dirs[i]);
+        for (String d : extdirs.list()) {
+            File dir = resolveFile(getProject(), d);
             if (dir.exists() && dir.isDirectory()) {
                 FileSet fs = new FileSet();
                 fs.setDir(dir);
@@ -770,7 +766,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
         if (preserveBC == null) {
             preserveBC = delegateIteratorToList() ? Boolean.TRUE : Boolean.FALSE;
         }
-        return preserveBC.booleanValue();
+        return preserveBC;
     }
 
     /**
@@ -778,8 +774,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
      * @since Ant 1.8.2
      */
     private static boolean containsWildcards(String path) {
-        return path != null
-            && (path.indexOf('*') > -1 || path.indexOf('?') > -1);
+        return path != null && (path.contains("*") || path.contains("?"));
     }
 
 }
