@@ -216,16 +216,12 @@ public class SelectSelector extends BaseSelectorContainer {
         validate();
 
         // Deal with if and unless properties first
-        if (!(passesConditions())) {
+        if (!passesConditions()) {
             return false;
         }
 
         Enumeration<FileSelector> e = selectorElements();
-        if (!e.hasMoreElements()) {
-            return true;
-        }
-        FileSelector f = e.nextElement();
-        return f.isSelected(basedir, filename, file);
+        return !e.hasMoreElements() || e.nextElement().isSelected(basedir, filename, file);
     }
 }
 
