@@ -38,17 +38,19 @@ import org.apache.tools.zip.ZipEncoding;
  * they are to be used.
  * <p>
  * TarEntries that are created from the header bytes read from
- * an archive are instantiated with the TarEntry( byte[] )
+ * an archive are instantiated with the TarEntry(byte[])
  * constructor. These entries will be used when extracting from
  * or listing the contents of an archive. These entries have their
  * header filled in using the header bytes. They also set the File
  * to null, since they reference an archive entry not a file.
+ * </p>
  * <p>
  * TarEntries that are created from Files that are to be written
- * into an archive are instantiated with the TarEntry( File )
+ * into an archive are instantiated with the TarEntry(File)
  * constructor. These entries have their header filled in using
  * the File's information. They also keep a reference to the File
  * for convenience when writing entries.
+ * </p>
  * <p>
  * Finally, TarEntries can be constructed from nothing but a name.
  * This allows the programmer to construct the entry by hand, for
@@ -56,8 +58,7 @@ import org.apache.tools.zip.ZipEncoding;
  * the archive, and the header information is constructed from
  * other information. In this case the header fields are set to
  * defaults and the File is set to null.
- *
- * <p>
+ * </p>
  * The C structure for a Tar Entry's header is:
  * <pre>
  * struct header {
@@ -84,8 +85,6 @@ import org.apache.tools.zip.ZipEncoding;
  * field is the binary representation of the number.
  * See TarUtils.parseOctalOrBinary.
  * </pre>
- *
- * <p>
  * The C structure for a old GNU Tar Entry's header is:
  * <pre>
  * struct oldgnu_header {
@@ -108,7 +107,6 @@ import org.apache.tools.zip.ZipEncoding;
  * char numbytes[12]; // offset 12
  * };
  * </pre>
- *
  */
 
 public class TarEntry implements TarConstants {
@@ -345,10 +343,7 @@ public class TarEntry implements TarConstants {
      */
     @Override
     public boolean equals(Object it) {
-        if (it == null || getClass() != it.getClass()) {
-            return false;
-        }
-        return equals((TarEntry) it);
+        return it != null && getClass() == it.getClass() && equals((TarEntry) it);
     }
 
     /**
@@ -379,7 +374,7 @@ public class TarEntry implements TarConstants {
      * @return This entry's name.
      */
     public String getName() {
-        return name.toString();
+        return name;
     }
 
     /**
@@ -406,7 +401,7 @@ public class TarEntry implements TarConstants {
      * @return This entry's link name.
      */
     public String getLinkName() {
-        return linkName.toString();
+        return linkName;
     }
 
     /**
@@ -427,7 +422,7 @@ public class TarEntry implements TarConstants {
      */
     @Deprecated
     public int getUserId() {
-        return (int) (userId & 0xffffffff);
+        return (int) userId;
     }
 
     /**
@@ -468,7 +463,7 @@ public class TarEntry implements TarConstants {
      */
     @Deprecated
     public int getGroupId() {
-        return (int) (groupId & 0xffffffff);
+        return (int) groupId;
     }
 
     /**
@@ -506,7 +501,7 @@ public class TarEntry implements TarConstants {
      * @return This entry's user name.
      */
     public String getUserName() {
-        return userName.toString();
+        return userName;
     }
 
     /**
@@ -524,7 +519,7 @@ public class TarEntry implements TarConstants {
      * @return This entry's group name.
      */
     public String getGroupName() {
-        return groupName.toString();
+        return groupName;
     }
 
     /**
@@ -747,15 +742,7 @@ public class TarEntry implements TarConstants {
             return file.isDirectory();
         }
 
-        if (linkFlag == LF_DIR) {
-            return true;
-        }
-
-        if (getName().endsWith("/")) {
-            return true;
-        }
-
-        return false;
+        return linkFlag == LF_DIR || getName().endsWith("/");
     }
 
     /**
@@ -763,13 +750,8 @@ public class TarEntry implements TarConstants {
      * @return <i>true</i> if it is a 'normal' file
      */
     public boolean isFile() {
-        if (file != null) {
-            return file.isFile();
-        }
-        if (linkFlag == LF_OLDNORM || linkFlag == LF_NORMAL) {
-            return true;
-        }
-        return !getName().endsWith("/");
+        return file != null ? file.isFile()
+                : linkFlag == LF_OLDNORM || linkFlag == LF_NORMAL || !getName().endsWith("/");
     }
 
     /**
@@ -991,39 +973,38 @@ public class TarEntry implements TarConstants {
 
         int type = evaluateType(header);
         switch (type) {
-        case FORMAT_OLDGNU: {
-            offset += ATIMELEN_GNU;
-            offset += CTIMELEN_GNU;
-            offset += OFFSETLEN_GNU;
-            offset += LONGNAMESLEN_GNU;
-            offset += PAD2LEN_GNU;
-            offset += SPARSELEN_GNU;
-            isExtended = TarUtils.parseBoolean(header, offset);
-            offset += ISEXTENDEDLEN_GNU;
-            realSize = TarUtils.parseOctal(header, offset, REALSIZELEN_GNU);
-            offset += REALSIZELEN_GNU;
-            break;
-        }
-        case FORMAT_POSIX:
-        default: {
-            String prefix = oldStyle
-                ? TarUtils.parseName(header, offset, PREFIXLEN)
-                : TarUtils.parseName(header, offset, PREFIXLEN, encoding);
-            // SunOS tar -E does not add / to directory names, so fix
-            // up to be consistent
-            if (isDirectory() && !name.endsWith("/")) {
-                name = name + "/";
+            case FORMAT_OLDGNU: {
+                offset += ATIMELEN_GNU;
+                offset += CTIMELEN_GNU;
+                offset += OFFSETLEN_GNU;
+                offset += LONGNAMESLEN_GNU;
+                offset += PAD2LEN_GNU;
+                offset += SPARSELEN_GNU;
+                isExtended = TarUtils.parseBoolean(header, offset);
+                offset += ISEXTENDEDLEN_GNU;
+                realSize = TarUtils.parseOctal(header, offset, REALSIZELEN_GNU);
+                offset += REALSIZELEN_GNU;
+                break;
             }
-            if (prefix.length() > 0) {
-                name = prefix + "/" + name;
+            case FORMAT_POSIX:
+            default: {
+                String prefix = oldStyle ? TarUtils.parseName(header, offset, PREFIXLEN)
+                        : TarUtils.parseName(header, offset, PREFIXLEN, encoding);
+                // SunOS tar -E does not add / to directory names, so fix
+                // up to be consistent
+                if (isDirectory() && !name.endsWith("/")) {
+                    name += "/";
+                }
+                if (!prefix.isEmpty()) {
+                    name = prefix + "/" + name;
+                }
             }
         }
-        }
     }
 
     /**
      * Strips Windows' drive letter as well as any leading slashes,
-     * turns path separators into forward slahes.
+     * turns path separators into forward slashes.
      */
     private static String normalizeFileName(String fileName,
                                             boolean preserveLeadingSlashes) {
@@ -1045,7 +1026,7 @@ public class TarEntry implements TarConstants {
                         fileName = fileName.substring(2);
                     }
                 }
-            } else if (osname.indexOf("netware") > -1) {
+            } else if (osname.contains("netware")) {
                 int colon = fileName.indexOf(':');
                 if (colon != -1) {
                     fileName = fileName.substring(colon + 1);
@@ -1083,10 +1064,10 @@ public class TarEntry implements TarConstants {
     /**
      * Check if buffer contents matches Ascii String.
      *
-     * @param expected
-     * @param buffer
-     * @param offset
-     * @param length
+     * @param expected String
+     * @param buffer byte[]
+     * @param offset int
+     * @param length int
      * @return {@code true} if buffer is the same as the expected string
      */
     private static boolean matchAsciiBuffer(String expected, byte[] buffer,
@@ -1105,22 +1086,22 @@ public class TarEntry implements TarConstants {
     /**
      * Compare byte buffers, optionally ignoring trailing nulls
      *
-     * @param buffer1
-     * @param offset1
-     * @param length1
-     * @param buffer2
-     * @param offset2
-     * @param length2
-     * @param ignoreTrailingNulls
+     * @param buffer1 byte[]
+     * @param offset1 int
+     * @param length1 int
+     * @param buffer2 byte[]
+     * @param offset2 int
+     * @param length2 int
+     * @param ignoreTrailingNulls boolean
      * @return {@code true} if buffer1 and buffer2 have same contents, having regard to trailing nulls
      */
     private static boolean isEqual(
             final byte[] buffer1, final int offset1, final int length1,
             final byte[] buffer2, final int offset2, final int length2,
             boolean ignoreTrailingNulls) {
-        int minLen=length1 < length2 ? length1 : length2;
-        for (int i=0; i < minLen; i++) {
-            if (buffer1[offset1+i] != buffer2[offset2+i]) {
+        int minLen = (length1 < length2) ? length1 : length2;
+        for (int i = 0; i < minLen; i++) {
+            if (buffer1[offset1 + i] != buffer2[offset2 + i]) {
                 return false;
             }
         }
@@ -1128,15 +1109,15 @@ public class TarEntry implements TarConstants {
             return true;
         }
         if (ignoreTrailingNulls) {
-            if (length1 > length2){
-                for(int i = length2; i < length1; i++){
-                    if (buffer1[offset1+i] != 0) {
+            if (length1 > length2) {
+                for (int i = length2; i < length1; i++) {
+                    if (buffer1[offset1 + i] != 0) {
                         return false;
                     }
                 }
             } else {
-                for (int i = length1; i < length2; i++){
-                    if (buffer2[offset2+i] != 0) {
+                for (int i = length1; i < length2; i++) {
+                    if (buffer2[offset2 + i] != 0) {
                         return false;
                     }
                 }
