@@ -22,8 +22,8 @@ import java.io.File;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
-import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.NoSuchElementException;
 import java.util.zip.ZipException;
 
 /**
@@ -31,8 +31,7 @@ import java.util.zip.ZipException;
  * access to the internal and external file attributes.
  *
  * <p>The extra data is expected to follow the recommendation of
- * {@link <a href="http://www.pkware.com/documents/casestudies/APPNOTE.TXT">
- * APPNOTE.txt</a>}:</p>
+ * <a href="http://www.pkware.com/documents/casestudies/APPNOTE.TXT">APPNOTE.txt</a>:</p>
  * <ul>
  *   <li>the extra byte array consists of a sequence of extra fields</li>
  *   <li>each extra fields starts by a two byte header id followed by
@@ -51,6 +50,7 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     public static final int PLATFORM_UNIX = 3;
     public static final int PLATFORM_FAT  = 0;
+    public static final int CRC_UNKNOWN = -1;
     private static final int SHORT_MASK = 0xFFFF;
     private static final int SHORT_SHIFT = 16;
     private static final byte[] EMPTY = new byte[0];
@@ -59,8 +59,7 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * The {@link java.util.zip.ZipEntry} base class only supports
      * the compression methods STORED and DEFLATED. We override the
      * field so that any compression methods can be used.
-     * <p>
-     * The default value -1 means that the method has not been specified.
+     * <p>The default value -1 means that the method has not been specified.</p>
      */
     private int method = -1;
 
@@ -75,11 +74,12 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
     private int internalAttributes = 0;
     private int platform = PLATFORM_FAT;
     private long externalAttributes = 0;
-    private LinkedHashMap<ZipShort, ZipExtraField> extraFields = null;
+    private ZipExtraField[] extraFields;
     private UnparseableExtraFieldData unparseableExtra = null;
     private String name = null;
     private byte[] rawName = null;
     private GeneralPurposeBit gpb = new GeneralPurposeBit();
+    private static final ZipExtraField[] noExtraFields = new ZipExtraField[0];
 
     /**
      * Creates a new zip entry with the specified name.
@@ -90,7 +90,7 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * @param name the name of the entry
      * @since 1.1
      */
-    public ZipEntry(String name) {
+    public ZipEntry(final String name) {
         super(name);
         setName(name);
     }
@@ -105,14 +105,13 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * @since 1.1
      * @throws ZipException on error
      */
-    public ZipEntry(java.util.zip.ZipEntry entry) throws ZipException {
+    public ZipEntry(final java.util.zip.ZipEntry entry) throws ZipException {
         super(entry);
         setName(entry.getName());
-        byte[] extra = entry.getExtra();
+        final byte[] extra = entry.getExtra();
         if (extra != null) {
             setExtraFields(ExtraFieldUtils.parse(extra, true,
-                                                 ExtraFieldUtils
-                                                 .UnparseableExtraField.READ));
+                    ExtraFieldUtils.UnparseableExtraField.READ));
         } else {
             // initializes extra data to an empty byte array
             setExtra();
@@ -131,11 +130,14 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * @throws ZipException on error
      * @since 1.1
      */
-    public ZipEntry(ZipEntry entry) throws ZipException {
+    public ZipEntry(final ZipEntry entry) throws ZipException {
         this((java.util.zip.ZipEntry) entry);
         setInternalAttributes(entry.getInternalAttributes());
         setExternalAttributes(entry.getExternalAttributes());
-        setExtraFields(entry.getExtraFields(true));
+        setExtraFields(getAllExtraFieldsNoCopy());
+        setPlatform(entry.getPlatform());
+        GeneralPurposeBit other = entry.getGeneralPurposeBit();
+        setGeneralPurposeBit(other == null ? null : (GeneralPurposeBit) other.clone());
     }
 
     /**
@@ -153,11 +155,13 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * the file is a directory.  If the file is not a directory a
      * potential trailing forward slash will be stripped from the
      * entry name.</p>
+     *
+     * @param inputFile File
+     * @param entryName String
      */
-    public ZipEntry(File inputFile, String entryName) {
-        this(inputFile.isDirectory() && !entryName.endsWith("/") ? 
-             entryName + "/" : entryName);
-        if (inputFile.isFile()){
+    public ZipEntry(final File inputFile, final String entryName) {
+        this(inputFile.isDirectory() && !entryName.endsWith("/") ? entryName + "/" : entryName);
+        if (inputFile.isFile()) {
             setSize(inputFile.length());
         }
         setTime(inputFile.lastModified());
@@ -166,16 +170,17 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Overwrite clone.
+     *
      * @return a cloned copy of this ZipEntry
      * @since 1.1
      */
     @Override
     public Object clone() {
-        ZipEntry e = (ZipEntry) super.clone();
+        final ZipEntry e = (ZipEntry) super.clone();
 
         e.setInternalAttributes(getInternalAttributes());
         e.setExternalAttributes(getExternalAttributes());
-        e.setExtraFields(getExtraFields(true));
+        e.setExtraFields(getAllExtraFieldsNoCopy());
         return e;
     }
 
@@ -196,10 +201,10 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * @param method compression method
      */
     @Override
-    public void setMethod(int method) {
+    public void setMethod(final int method) {
         if (method < 0) {
-            throw new IllegalArgumentException(
-                    "ZIP compression method can not be negative: " + method);
+            throw new IllegalArgumentException("ZIP compression method can not be negative: "
+                    + method);
         }
         this.method = method;
     }
@@ -216,15 +221,17 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Sets the internal file attributes.
+     *
      * @param value an <code>int</code> value
      * @since 1.1
      */
-    public void setInternalAttributes(int value) {
+    public void setInternalAttributes(final int value) {
         internalAttributes = value;
     }
 
     /**
      * Retrieves the external file attributes.
+     *
      * @return the external file attributes
      * @since 1.1
      */
@@ -234,20 +241,22 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Sets the external file attributes.
+     *
      * @param value an <code>long</code> value
      * @since 1.1
      */
-    public void setExternalAttributes(long value) {
+    public void setExternalAttributes(final long value) {
         externalAttributes = value;
     }
 
     /**
      * Sets Unix permissions in a way that is understood by Info-Zip's
      * unzip command.
+     *
      * @param mode an <code>int</code> value
      * @since Ant 1.5.2
      */
-    public void setUnixMode(int mode) {
+    public void setUnixMode(final int mode) {
         // CheckStyle:MagicNumberCheck OFF - no point
         setExternalAttributes((mode << SHORT_SHIFT)
                               // MS-DOS read-only attribute
@@ -260,12 +269,13 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Unix permission.
+     *
      * @return the unix permissions
      * @since Ant 1.6
      */
     public int getUnixMode() {
-        return platform != PLATFORM_UNIX ? 0 :
-            (int) ((getExternalAttributes() >> SHORT_SHIFT) & SHORT_MASK);
+        return platform != PLATFORM_UNIX ? 0
+                : (int) ((getExternalAttributes() >> SHORT_SHIFT) & SHORT_MASK);
     }
 
     /**
@@ -283,58 +293,104 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Set the platform (UNIX or FAT).
+     *
      * @param platform an <code>int</code> value - 0 is FAT, 3 is UNIX
      * @since 1.9
      */
-    protected void setPlatform(int platform) {
+    protected void setPlatform(final int platform) {
         this.platform = platform;
     }
 
     /**
      * Replaces all currently attached extra fields with the new array.
+     *
      * @param fields an array of extra fields
      * @since 1.1
      */
-    public void setExtraFields(ZipExtraField[] fields) {
-        extraFields = new LinkedHashMap<ZipShort, ZipExtraField>();
+    public void setExtraFields(final ZipExtraField[] fields) {
+        List<ZipExtraField> newFields = new ArrayList<>();
         for (ZipExtraField field : fields) {
             if (field instanceof UnparseableExtraFieldData) {
                 unparseableExtra = (UnparseableExtraFieldData) field;
             } else {
-                extraFields.put(field.getHeaderId(), field);
+                newFields.add(field);
             }
         }
+        extraFields = newFields.toArray(new ZipExtraField[newFields.size()]);
         setExtra();
     }
 
     /**
      * Retrieves all extra fields that have been parsed successfully.
+     *
      * @return an array of the extra fields
      */
     public ZipExtraField[] getExtraFields() {
-        return getExtraFields(false);
+        return getParseableExtraFields();
     }
 
     /**
      * Retrieves extra fields.
+     *
      * @param includeUnparseable whether to also return unparseable
      * extra fields as {@link UnparseableExtraFieldData} if such data
      * exists.
      * @return an array of the extra fields
      * @since 1.1
      */
-    public ZipExtraField[] getExtraFields(boolean includeUnparseable) {
+    public ZipExtraField[] getExtraFields(final boolean includeUnparseable) {
+        return includeUnparseable ? getAllExtraFields() : getParseableExtraFields();
+    }
+
+    private ZipExtraField[] getParseableExtraFieldsNoCopy() {
         if (extraFields == null) {
-            return !includeUnparseable || unparseableExtra == null
-                ? new ZipExtraField[0]
-                : new ZipExtraField[] { unparseableExtra };
+            return noExtraFields;
         }
-        List<ZipExtraField> result =
-            new ArrayList<ZipExtraField>(extraFields.values());
-        if (includeUnparseable && unparseableExtra != null) {
-            result.add(unparseableExtra);
+        return extraFields;
+    }
+
+    private ZipExtraField[] getParseableExtraFields() {
+        final ZipExtraField[] parseableExtraFields = getParseableExtraFieldsNoCopy();
+        return (parseableExtraFields == extraFields) ? copyOf(parseableExtraFields)
+                : parseableExtraFields;
+    }
+
+    private ZipExtraField[] copyOf(ZipExtraField[] src) {
+        return copyOf(src, src.length);
+    }
+
+    private ZipExtraField[] copyOf(ZipExtraField[] src, int length) {
+        ZipExtraField[] cpy = new ZipExtraField[length];
+        System.arraycopy(src, 0, cpy, 0, Math.min(src.length, length));
+        return cpy;
+    }
+
+    private ZipExtraField[] getMergedFields() {
+        final ZipExtraField[] zipExtraFields = copyOf(extraFields, extraFields.length + 1);
+        zipExtraFields[extraFields.length] = unparseableExtra;
+        return zipExtraFields;
+    }
+
+    private ZipExtraField[] getUnparseableOnly() {
+        return unparseableExtra == null ? noExtraFields : new ZipExtraField[] {unparseableExtra};
+    }
+
+    private ZipExtraField[] getAllExtraFields() {
+        final ZipExtraField[] allExtraFieldsNoCopy = getAllExtraFieldsNoCopy();
+        return (allExtraFieldsNoCopy == extraFields) ? copyOf(allExtraFieldsNoCopy)
+                : allExtraFieldsNoCopy;
+    }
+
+    /**
+     * Get all extra fields, including unparseable ones.
+     *
+     * @return An array of all extra fields. Not necessarily a copy of internal data structures, hence private method
+     */
+    private ZipExtraField[] getAllExtraFieldsNoCopy() {
+        if (extraFields == null) {
+            return getUnparseableOnly();
         }
-        return result.toArray(new ZipExtraField[0]);
+        return unparseableExtra != null ? getMergedFields() : extraFields;
     }
 
     /**
@@ -343,17 +399,24 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      *
      * <p>If no extra field of the same type exists, the field will be
      * added as last field.</p>
+     *
      * @param ze an extra field
      * @since 1.1
      */
-    public void addExtraField(ZipExtraField ze) {
+    public void addExtraField(final ZipExtraField ze) {
         if (ze instanceof UnparseableExtraFieldData) {
             unparseableExtra = (UnparseableExtraFieldData) ze;
         } else {
             if (extraFields == null) {
-                extraFields = new LinkedHashMap<ZipShort, ZipExtraField>();
+                extraFields = new ZipExtraField[] {ze};
+            } else {
+                if (getExtraField(ze.getHeaderId()) !=  null) {
+                    removeExtraField(ze.getHeaderId());
+                }
+                final ZipExtraField[] zipExtraFields = copyOf(extraFields, extraFields.length + 1);
+                zipExtraFields[extraFields.length] = ze;
+                extraFields = zipExtraFields;
             }
-            extraFields.put(ze.getHeaderId(), ze);
         }
         setExtra();
     }
@@ -363,19 +426,23 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * of the same type.
      *
      * <p>The new extra field will be the first one.</p>
+     *
      * @param ze an extra field
      * @since 1.1
      */
-    public void addAsFirstExtraField(ZipExtraField ze) {
+    public void addAsFirstExtraField(final ZipExtraField ze) {
         if (ze instanceof UnparseableExtraFieldData) {
             unparseableExtra = (UnparseableExtraFieldData) ze;
         } else {
-            LinkedHashMap<ZipShort, ZipExtraField> copy = extraFields;
-            extraFields = new LinkedHashMap<ZipShort, ZipExtraField>();
-            extraFields.put(ze.getHeaderId(), ze);
+            if (getExtraField(ze.getHeaderId()) != null) {
+                removeExtraField(ze.getHeaderId());
+            }
+            ZipExtraField[] copy = extraFields;
+            int newLen = extraFields != null ? extraFields.length + 1 : 1;
+            extraFields = new ZipExtraField[newLen];
+            extraFields[0] = ze;
             if (copy != null) {
-                copy.remove(ze.getHeaderId());
-                extraFields.putAll(copy);
+                System.arraycopy(copy, 0, extraFields, 1, extraFields.length - 1);
             }
         }
         setExtra();
@@ -383,16 +450,24 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Remove an extra field.
+     *
      * @param type the type of extra field to remove
      * @since 1.1
      */
-    public void removeExtraField(ZipShort type) {
+    public void removeExtraField(final ZipShort type) {
         if (extraFields == null) {
-            throw new java.util.NoSuchElementException();
+            throw new NoSuchElementException();
         }
-        if (extraFields.remove(type) == null) {
-            throw new java.util.NoSuchElementException();
+        List<ZipExtraField> newResult = new ArrayList<>();
+        for (ZipExtraField extraField : extraFields) {
+            if (!type.equals(extraField.getHeaderId())) {
+                newResult.add(extraField);
+            }
         }
+        if (extraFields.length == newResult.size()) {
+            throw new NoSuchElementException();
+        }
+        extraFields = newResult.toArray(new ZipExtraField[newResult.size()]);
         setExtra();
     }
 
@@ -401,7 +476,7 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      */
     public void removeUnparseableExtraFieldData() {
         if (unparseableExtra == null) {
-            throw new java.util.NoSuchElementException();
+            throw new NoSuchElementException();
         }
         unparseableExtra = null;
         setExtra();
@@ -410,11 +485,16 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
     /**
      * Looks up an extra field by its header id.
      *
+     * @param type ZipShort
      * @return null if no such field exists.
      */
-    public ZipExtraField getExtraField(ZipShort type) {
+    public ZipExtraField getExtraField(final ZipShort type) {
         if (extraFields != null) {
-            return extraFields.get(type);
+            for (ZipExtraField extraField : extraFields) {
+                if (type.equals(extraField.getHeaderId())) {
+                    return extraField;
+                }
+            }
         }
         return null;
     }
@@ -432,21 +512,21 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * Parses the given bytes as extra field data and consumes any
      * unparseable data as an {@link UnparseableExtraFieldData}
      * instance.
+     *
      * @param extra an array of bytes to be parsed into extra fields
      * @throws RuntimeException if the bytes cannot be parsed
-     * @since 1.1
      * @throws RuntimeException on error
+     * @since 1.1
      */
     @Override
-    public void setExtra(byte[] extra) throws RuntimeException {
+    public void setExtra(final byte[] extra) throws RuntimeException {
         try {
-            ZipExtraField[] local =
-                ExtraFieldUtils.parse(extra, true,
-                                      ExtraFieldUtils.UnparseableExtraField.READ);
+            final ZipExtraField[] local = ExtraFieldUtils.parse(extra, true,
+                    ExtraFieldUtils.UnparseableExtraField.READ);
             mergeExtraFields(local, true);
-        } catch (ZipException e) {
+        } catch (final ZipException e) {
             // actually this is not be possible as of Ant 1.8.1
-            throw new RuntimeException("Error parsing extra fields for entry: "
+            throw new RuntimeException("Error parsing extra fields for entry: " //NOSONAR
                                        + getName() + " - " + e.getMessage(), e);
         }
     }
@@ -465,30 +545,33 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Sets the central directory part of extra fields.
+     *
+     * @param b boolean
      */
-    public void setCentralDirectoryExtra(byte[] b) {
+    public void setCentralDirectoryExtra(final byte[] b) {
         try {
-            ZipExtraField[] central =
-                ExtraFieldUtils.parse(b, false,
-                                      ExtraFieldUtils.UnparseableExtraField.READ);
+            final ZipExtraField[] central = ExtraFieldUtils.parse(b, false,
+                    ExtraFieldUtils.UnparseableExtraField.READ);
             mergeExtraFields(central, false);
-        } catch (ZipException e) {
-            throw new RuntimeException(e.getMessage(), e);
+        } catch (final ZipException e) {
+            throw new RuntimeException(e.getMessage(), e); //NOSONAR
         }
     }
 
     /**
      * Retrieves the extra data for the local file data.
+     *
      * @return the extra data for local file
      * @since 1.1
      */
     public byte[] getLocalFileDataExtra() {
-        byte[] extra = getExtra();
+        final byte[] extra = getExtra();
         return extra != null ? extra : EMPTY;
     }
 
     /**
      * Retrieves the extra data for the central directory.
+     *
      * @return the central directory extra data
      * @since 1.1
      */
@@ -501,17 +584,20 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      *
      * <p>This either stores the size for later usage or invokes
      * setCompressedSize via reflection.</p>
+     *
      * @param size the size to use
      * @deprecated since 1.7.
      *             Use setCompressedSize directly.
      * @since 1.2
      */
-    public void setComprSize(long size) {
+    @Deprecated
+    public void setComprSize(final long size) {
         setCompressedSize(size);
     }
 
     /**
      * Get the name of the entry.
+     *
      * @return the entry name
      * @since 1.9
      */
@@ -522,6 +608,7 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Is this entry a directory?
+     *
      * @return true if the entry is a directory
      * @since 1.10
      */
@@ -532,11 +619,11 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Set the name of the entry.
+     *
      * @param name the name to use
      */
     protected void setName(String name) {
-        if (name != null && getPlatform() == PLATFORM_FAT
-            && name.indexOf("/") == -1) {
+        if (name != null && getPlatform() == PLATFORM_FAT && !name.contains("/")) {
             name = name.replace('\\', '/');
         }
         this.name = name;
@@ -544,6 +631,7 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Gets the uncompressed size of the entry data.
+     *
      * @return the entry size
      */
     @Override
@@ -553,12 +641,13 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * Sets the uncompressed size of the entry data.
+     *
      * @param size the uncompressed size in bytes
      * @exception IllegalArgumentException if the specified size is less
      *            than 0
      */
     @Override
-    public void setSize(long size) {
+    public void setSize(final long size) {
         if (size < 0) {
             throw new IllegalArgumentException("invalid entry size");
         }
@@ -568,12 +657,13 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
     /**
      * Sets the name using the raw bytes and the string created from
      * it by guessing or using the configured encoding.
+     *
      * @param name the name to use created from the raw bytes using
      * the guessed or configured encoding
      * @param rawName the bytes originally read as name from the
      * archive
      */
-    protected void setName(String name, byte[] rawName) {
+    protected void setName(final String name, final byte[] rawName) {
         setName(name);
         this.rawName = rawName;
     }
@@ -584,10 +674,12 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      *
      * <p>This method will return null if this instance has not been
      * read from an archive.</p>
+     *
+     * @return byte[]
      */
     public byte[] getRawName() {
         if (rawName != null) {
-            byte[] b = new byte[rawName.length];
+            final byte[] b = new byte[rawName.length];
             System.arraycopy(rawName, 0, b, 0, rawName.length);
             return b;
         }
@@ -597,6 +689,7 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
     /**
      * Get the hashCode of the entry.
      * This uses the name as the hashcode.
+     *
      * @return a hashcode.
      * @since Ant 1.7
      */
@@ -604,13 +697,15 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
     public int hashCode() {
         // this method has severe consequences on performance. We cannot rely
         // on the super.hashCode() method since super.getName() always return
-        // the empty string in the current implemention (there's no setter)
+        // the empty string in the current implementation (there's no setter)
         // so it is basically draining the performance of a hashmap lookup
         return getName().hashCode();
     }
 
     /**
      * The "general purpose bit" field.
+     *
+     * @return GeneralPurposeBit
      */
     public GeneralPurposeBit getGeneralPurposeBit() {
         return gpb;
@@ -618,8 +713,10 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
 
     /**
      * The "general purpose bit" field.
+     *
+     * @param b GeneralPurposeBit
      */
-    public void setGeneralPurposeBit(GeneralPurposeBit b) {
+    public void setGeneralPurposeBit(final GeneralPurposeBit b) {
         gpb = b;
     }
 
@@ -628,15 +725,16 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * data - otherwise merge the fields assuming the existing fields
      * and the new fields stem from different locations inside the
      * archive.
+     *
      * @param f the extra fields to merge
      * @param local whether the new fields originate from local data
      */
-    private void mergeExtraFields(ZipExtraField[] f, boolean local)
+    private void mergeExtraFields(final ZipExtraField[] f, final boolean local)
         throws ZipException {
         if (extraFields == null) {
             setExtraFields(f);
         } else {
-            for (ZipExtraField element : f) {
+            for (final ZipExtraField element : f) {
                 ZipExtraField existing;
                 if (element instanceof UnparseableExtraFieldData) {
                     existing = unparseableExtra;
@@ -647,12 +745,11 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
                     addExtraField(element);
                 } else {
                     if (local
-                        || !(existing
-                             instanceof CentralDirectoryParsingZipExtraField)) {
-                        byte[] b = element.getLocalFileDataData();
+                        || !(existing instanceof CentralDirectoryParsingZipExtraField)) {
+                        final byte[] b = element.getLocalFileDataData();
                         existing.parseFromLocalFileData(b, 0, b.length);
                     } else {
-                        byte[] b = element.getCentralDirectoryData();
+                        final byte[] b = element.getCentralDirectoryData();
                         ((CentralDirectoryParsingZipExtraField) existing)
                             .parseFromCentralDirectoryData(b, 0, b.length);
                     }
@@ -671,16 +768,16 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
      * @see java.lang.Object#equals(java.lang.Object)
      */
     @Override
-    public boolean equals(Object obj) {
+    public boolean equals(final Object obj) {
         if (this == obj) {
             return true;
         }
         if (obj == null || getClass() != obj.getClass()) {
             return false;
         }
-        ZipEntry other = (ZipEntry) obj;
-        String myName = getName();
-        String otherName = other.getName();
+        final ZipEntry other = (ZipEntry) obj;
+        final String myName = getName();
+        final String otherName = other.getName();
         if (myName == null) {
             if (otherName != null) {
                 return false;
@@ -705,10 +802,8 @@ public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
             && getSize() == other.getSize()
             && getCrc() == other.getCrc()
             && getCompressedSize() == other.getCompressedSize()
-            && Arrays.equals(getCentralDirectoryExtra(),
-                             other.getCentralDirectoryExtra())
-            && Arrays.equals(getLocalFileDataExtra(),
-                             other.getLocalFileDataExtra())
+            && Arrays.equals(getCentralDirectoryExtra(), other.getCentralDirectoryExtra())
+            && Arrays.equals(getLocalFileDataExtra(), other.getLocalFileDataExtra())
             && gpb.equals(other.gpb);
     }
 }
