@@ -472,7 +472,7 @@ public class ZipFile implements Closeable {
     }
 
     /**
-     * Reads an individual entry of the central directory, creats an
+     * Reads an individual entry of the central directory, creates an
      * ZipEntry from it and adds it to the global maps.
      *
      * @param noUTF8Flag map used to collect entries that don't have
@@ -778,7 +778,7 @@ public class ZipFile implements Closeable {
 
     /**
      * Searches the archive backwards from minDistance to maxDistance
-     * for the given signature, positions the RandomaccessFile right
+     * for the given signature, positions the RandomAccessFile right
      * at the signature if it has been found.
      */
     private boolean tryToLocateSignature(final long minDistanceFromEnd,
@@ -889,11 +889,7 @@ public class ZipFile implements Closeable {
             }
 
             final String name = ze.getName();
-            LinkedList<ZipEntry> entriesOfThatName = nameMap.get(name);
-            if (entriesOfThatName == null) {
-                entriesOfThatName = new LinkedList<>();
-                nameMap.put(name, entriesOfThatName);
-            }
+            LinkedList<ZipEntry> entriesOfThatName = nameMap.computeIfAbsent(name, k -> new LinkedList<>());
             entriesOfThatName.addLast(ze);
         }
     }
