@@ -24,7 +24,7 @@ import java.net.URL;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Enumeration;
-import java.util.List;
+
 import org.apache.tools.ant.types.Path;
 import org.apache.tools.ant.util.FileUtils;
 import org.junit.Before;
@@ -52,9 +52,9 @@ public class AntClassLoaderDelegationTest {
     }
 
     /** Sample resource present in build/testcases/ */
-    private static final String TEST_RESOURCE
-        = "apache/tools/ant/IncludeTest.class";
+    private static final String TEST_RESOURCE = "apache/tools/ant/IncludeTest.class";
 
+    @SuppressWarnings("resource")
     @Test
     public void testFindResources() throws Exception {
         // This path should contain the class files for these testcases:
@@ -73,14 +73,15 @@ public class AntClassLoaderDelegationTest {
             FILE_UTILS.toURI(buildTestcases) + "org/" + TEST_RESOURCE);
         URL urlFromParent = new URL("http://ant.apache.org/" + TEST_RESOURCE);
         assertEquals("correct resources (regular delegation order)",
-            Arrays.asList(new URL[] {urlFromParent, urlFromPath}),
-            enum2List(acl.getResources(TEST_RESOURCE)));
+            Arrays.asList(urlFromParent, urlFromPath),
+                Collections.list(acl.getResources(TEST_RESOURCE)));
         acl = new AntClassLoader(parent, p, path, false);
         assertEquals("correct resources (reverse delegation order)",
-            Arrays.asList(new URL[] {urlFromPath, urlFromParent}),
-            enum2List(acl.getResources(TEST_RESOURCE)));
+            Arrays.asList(urlFromPath, urlFromParent),
+                Collections.list(acl.getResources(TEST_RESOURCE)));
     }
 
+    @SuppressWarnings("resource")
     @Test
     public void testFindIsolateResources() throws Exception {
         String buildTestcases = System.getProperty("build.tests");
@@ -96,29 +97,26 @@ public class AntClassLoaderDelegationTest {
         AntClassLoader acl = new AntClassLoader(parent, p, path, false);
         acl.setIsolated(true);
         assertEquals("correct resources (reverse delegation order)",
-            Arrays.asList(new URL[] {urlFromPath}),
-            enum2List(acl.getResources(TEST_RESOURCE)));
+                Collections.singletonList(urlFromPath),
+                Collections.list(acl.getResources(TEST_RESOURCE)));
     }
-    
-    private static List enum2List(Enumeration e) {
-        return Collections.list(e);
-    }
-    
+
     /** Special loader that just knows how to find TEST_RESOURCE. */
     private static final class ParentLoader extends ClassLoader {
-        
-        public ParentLoader() {}
-        
-        protected Enumeration findResources(String name) throws IOException {
+
+        public ParentLoader() {
+        }
+
+        protected Enumeration<URL> findResources(String name) throws IOException {
             if (name.equals(TEST_RESOURCE)) {
                 return Collections.enumeration(
                     Collections.singleton(
                         new URL("http://ant.apache.org/" + name)));
             } else {
-                return Collections.enumeration(Collections.EMPTY_SET);
+                return Collections.enumeration(Collections.emptySet());
             }
         }
-        
+
     }
-    
+
 }
