@@ -24,12 +24,12 @@ import org.junit.Rule;
 import org.junit.Test;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
+import static org.hamcrest.Matchers.instanceOf;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertThat;
 
 public class UnknownElementTest {
 
@@ -50,8 +50,7 @@ public class UnknownElementTest {
     /**
      * Not really a UnknownElement test but rather one of "what
      * information is available in taskFinished".
-     * @see <a href="https://issues.apache.org/bugzilla/show_bug.cgi?id=26197">
-     *     https://issues.apache.org/bugzilla/show_bug.cgi?id=26197</a>
+     * @see <a href="https://issues.apache.org/bugzilla/show_bug.cgi?id=26197">bug 26197</a>
      */
     @Test
     @Ignore("Previously disabled through naming convention")
@@ -59,23 +58,30 @@ public class UnknownElementTest {
         buildRule.getProject().addBuildListener(new BuildListener() {
                 public void buildStarted(BuildEvent event) {
                 }
+
                 public void buildFinished(BuildEvent event) {
                 }
+
                 public void targetStarted(BuildEvent event) {
                 }
+
                 public void targetFinished(BuildEvent event) {
                 }
+
                 public void taskStarted(BuildEvent event) {
                     assertTaskProperties(event.getTask());
                 }
+
                 public void taskFinished(BuildEvent event) {
                     assertTaskProperties(event.getTask());
                 }
+
                 public void messageLogged(BuildEvent event) {
                 }
+
                 private void assertTaskProperties(Task ue) {
                     assertNotNull(ue);
-                    assertTrue(ue instanceof UnknownElement);
+                    assertThat(ue, instanceOf(UnknownElement.class));
                     Task t = ((UnknownElement) ue).getTask();
                     assertNotNull(t);
                     assertEquals("org.apache.tools.ant.taskdefs.Echo",
@@ -87,16 +93,19 @@ public class UnknownElementTest {
 
     public static class Child extends Task {
         Parent parent;
+
         public void injectParent(Parent parent) {
             this.parent = parent;
         }
+
         public void execute() {
             parent.fromChild();
         }
     }
 
     public static class Parent extends Task implements TaskContainer {
-        List children = new ArrayList();
+        List<Task> children = new ArrayList<>();
+
         public void addTask(Task t) {
             children.add(t);
         }
@@ -106,8 +115,8 @@ public class UnknownElementTest {
         }
 
         public void execute() {
-            for (Iterator i = children.iterator(); i.hasNext();) {
-                UnknownElement el = (UnknownElement) i.next();
+            for (Task task : children) {
+                UnknownElement el = (UnknownElement) task;
                 el.maybeConfigure();
                 Child child = (Child) el.getRealThing();
                 child.injectParent(this);
