@@ -18,10 +18,14 @@
 
 package org.apache.tools.ant.filters;
 
-import static org.apache.tools.ant.AntAssert.assertContains;
-import static org.apache.tools.ant.AntAssert.assertNotContains;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.hamcrest.Matchers.both;
+import static org.hamcrest.Matchers.containsString;
+import static org.hamcrest.Matchers.endsWith;
+import static org.hamcrest.Matchers.hasKey;
+import static org.hamcrest.Matchers.not;
+import static org.hamcrest.Matchers.startsWith;
+import static org.junit.Assert.assertThat;
+import static org.junit.Assume.assumeThat;
 
 import java.io.FileReader;
 import java.io.IOException;
@@ -29,7 +33,6 @@ import java.io.Reader;
 
 import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.util.FileUtils;
-import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -51,99 +54,101 @@ public class TokenFilterTest {
 
     /** make sure tokenfilter exists */
     @Test
-    public void testTokenfilter() throws IOException {
+    public void testTokenfilter() {
         buildRule.executeTarget("tokenfilter");
     }
 
     @Test
-    public void testTrimignore() throws IOException {
+    public void testTrimignore() {
         buildRule.executeTarget("trimignore");
-        assertContains("Hello-World", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("Hello-World"));
     }
 
     @Test
-    public void testStringTokenizer() throws IOException {
+    public void testStringTokenizer() {
         buildRule.executeTarget("stringtokenizer");
-        assertContains("#This#is#a#number#of#words#", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("#This#is#a#number#of#words#"));
     }
 
     @Test
     public void testUnixLineOutput() throws IOException {
         buildRule.executeTarget("unixlineoutput");
-        assertContains("\nThis\nis\na\nnumber\nof\nwords\n",
-                getFileString(buildRule.getProject().getProperty("output") + "/unixlineoutput"));
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/unixlineoutput"),
+                containsString("\nThis\nis\na\nnumber\nof\nwords\n"));
     }
 
     @Test
     public void testDosLineOutput() throws IOException {
-
         buildRule.executeTarget("doslineoutput");
-        assertContains("\r\nThis\r\nis\r\na\r\nnumber\r\nof\r\nwords\r\n",
-                getFileString(buildRule.getProject().getProperty("output") + "/doslineoutput"));
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/doslineoutput"),
+                containsString("\r\nThis\r\nis\r\na\r\nnumber\r\nof\r\nwords\r\n"));
     }
 
     @Test
     public void testFileTokenizer() throws IOException {
         buildRule.executeTarget("filetokenizer");
-        String contents = getFileString(buildRule.getProject().getProperty("output") + "/filetokenizer");
-        assertContains("   of words", contents);
-        assertNotContains(" This is", contents);
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/filetokenizer"),
+                both(containsString("   of words")).and(not(containsString(" This is"))));
     }
 
     @Test
     public void testReplaceString() throws IOException {
         buildRule.executeTarget("replacestring");
-        assertContains("this is the moon",
-                getFileString(buildRule.getProject().getProperty("output") + "/replacestring"));
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/replacestring"),
+                containsString("this is the moon"));
     }
 
     @Test
-    public void testReplaceStrings() throws IOException {
+    public void testReplaceStrings() {
         buildRule.executeTarget("replacestrings");
-        assertContains("bar bar bar", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("bar bar bar"));
     }
 
     @Test
     public void testContainsString() throws IOException {
         buildRule.executeTarget("containsstring");
-        String contents = getFileString(buildRule.getProject().getProperty("output") + "/containsstring");
-        assertContains("this is a line contains foo", contents);
-        assertNotContains("this line does not", contents);
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/containsstring"),
+                both(containsString("this is a line contains foo"))
+                        .and(not(containsString("this line does not"))));
     }
 
     @Test
     public void testReplaceRegex() throws IOException {
 
         buildRule.executeTarget("hasregex");
-        Assume.assumeTrue("Regex not present",
-                getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp").contains("bye world"));
+        assumeThat("Regex not present",
+                getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp"),
+                containsString("bye world"));
 
         buildRule.executeTarget("replaceregex");
         String contents = getFileString(buildRule.getProject().getProperty("output") + "/replaceregex");
-        assertContains("world world world world", contents);
-        assertContains("dog Cat dog", contents);
-        assertContains("moon Sun Sun", contents);
-        assertContains("found WhiteSpace", contents);
-        assertContains("Found digits [1234]", contents);
-        assertNotContains("This is a line with digits", contents);
+        assertThat(contents, containsString("world world world world"));
+        assertThat(contents, containsString("dog Cat dog"));
+        assertThat(contents, containsString("moon Sun Sun"));
+        assertThat(contents, containsString("found WhiteSpace"));
+        assertThat(contents, containsString("Found digits [1234]"));
+        assertThat(contents, not(containsString("This is a line with digits")));
     }
 
     @Test
     public void testFilterReplaceRegex() throws IOException {
         buildRule.executeTarget("hasregex");
-        Assume.assumeTrue("Regex not present",
-                getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp").contains("bye world"));
+        assumeThat("Regex not present",
+                getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp"),
+                containsString("bye world"));
 
         buildRule.executeTarget("filterreplaceregex");
-        String contents = getFileString(buildRule.getProject().getProperty("output") + "/filterreplaceregex");
-        assertContains("world world world world", contents);
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/filterreplaceregex"),
+                containsString("world world world world"));
 
     }
 
     @Test
     public void testHandleDollerMatch() throws IOException {
         buildRule.executeTarget("hasregex");
-        Assume.assumeTrue("Regex not present", getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp").contains("bye world"));
+        assumeThat("Regex not present",
+                getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp"),
+                containsString("bye world"));
 
         buildRule.executeTarget("dollermatch");
     }
@@ -152,99 +157,110 @@ public class TokenFilterTest {
     public void testTrimFile() throws IOException {
         buildRule.executeTarget("trimfile");
         String contents = getFileString(buildRule.getProject().getProperty("output") + "/trimfile");
-        assertTrue("no ws at start", contents.startsWith("This is th"));
-        assertTrue("no ws at end", contents.endsWith("second line."));
-        assertContains("  This is the second", contents);
+        assertThat("no ws at start", contents, startsWith("This is th"));
+        assertThat("no ws at end", contents, endsWith("second line."));
+        assertThat(contents, containsString("  This is the second"));
     }
 
     @Test
     public void testTrimFileByLine() throws IOException {
         buildRule.executeTarget("trimfilebyline");
         String contents = getFileString(buildRule.getProject().getProperty("output") + "/trimfilebyline");
-        assertFalse("no ws at start", contents.startsWith("This is th"));
-        assertFalse("no ws at end", contents.endsWith("second line."));
-        assertNotContains("  This is the second", contents);
-        assertContains("file.\nThis is the second", contents);
+        assertThat("no ws at start", contents, not(startsWith("This is th")));
+        assertThat("no ws at end", contents, not(endsWith("second line.")));
+        assertThat(contents, not(containsString("  This is the second")));
+        assertThat(contents, containsString("file.\nThis is the second"));
     }
 
     @Test
     public void testFilterReplaceString() throws IOException {
         buildRule.executeTarget("filterreplacestring");
-        String contents = getFileString(buildRule.getProject().getProperty("output") + "/filterreplacestring");
-        assertContains("This is the moon", contents);
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/filterreplacestring"),
+                containsString("This is the moon"));
     }
 
     @Test
-    public void testFilterReplaceStrings() throws IOException {
+    public void testFilterReplaceStrings() {
         buildRule.executeTarget("filterreplacestrings");
-        assertContains("bar bar bar", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("bar bar bar"));
     }
 
     @Test
     public void testContainsRegex() throws IOException {
         buildRule.executeTarget("hasregex");
-        Assume.assumeTrue("Regex not present", getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp").contains("bye world"));
+        assumeThat("Regex not present",
+                getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp"),
+                containsString("bye world"));
 
-        //expectFileContains(buildRule.getProject().getProperty("output") + "/replaceregexp", "bye world");
+        // assertThat(buildRule.getProject().getProperty("output") + "/replaceregexp",
+        // containsString("bye world"));
 
         buildRule.executeTarget("containsregex");
         String contents = getFileString(buildRule.getProject().getProperty("output") + "/containsregex");
-        assertContains("hello world", contents);
-        assertNotContains("this is the moon", contents);
-        assertContains("World here", contents);
+        assertThat(contents, containsString("hello world"));
+        assertThat(contents, not(containsString("this is the moon")));
+        assertThat(contents, containsString("World here"));
     }
 
     @Test
     public void testFilterContainsRegex() throws IOException {
         buildRule.executeTarget("hasregex");
-        Assume.assumeTrue("Regex not present", getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp").contains("bye world"));
+        assumeThat("Regex not present",
+                getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp"),
+                containsString("bye world"));
 
         buildRule.executeTarget("filtercontainsregex");
         String contents = getFileString(buildRule.getProject().getProperty("output") + "/filtercontainsregex");
-        assertContains("hello world", contents);
-        assertNotContains("this is the moon", contents);
-        assertContains("World here", contents);
+        assertThat(contents, containsString("hello world"));
+        assertThat(contents, not(containsString("this is the moon")));
+        assertThat(contents, containsString("World here"));
     }
 
     @Test
     public void testContainsRegex2() throws IOException {
         buildRule.executeTarget("hasregex");
-        Assume.assumeTrue("Regex not present", getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp").contains("bye world"));
+        assumeThat("Regex not present",
+                getFileString(buildRule.getProject().getProperty("output") + "/replaceregexp"),
+                containsString("bye world"));
 
         buildRule.executeTarget("containsregex2");
-        String contents = getFileString(buildRule.getProject().getProperty("output") + "/containsregex2");
-        assertContains("void register_bits();", contents);
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/containsregex2"),
+                containsString("void register_bits();"));
     }
 
     @Test
     public void testDeleteCharacters() throws IOException {
         buildRule.executeTarget("deletecharacters");
         String contents = getFileString(buildRule.getProject().getProperty("output") + "/deletechars");
-        assertNotContains("#", contents);
-        assertNotContains("*", contents);
-        assertContains("This is some ", contents);
+        assertThat(contents, not(containsString("#")));
+        assertThat(contents, not(containsString("*")));
+        assertThat(contents, containsString("This is some "));
     }
 
     @Test
     public void testScriptFilter() throws IOException {
-        Assume.assumeTrue("Project does not have 'testScriptFilter' target",
-                buildRule.getProject().getTargets().contains("testScriptFilter"));
+        assumeThat("Project does not have 'testScriptFilter' target",
+                buildRule.getProject().getTargets(), hasKey("testScriptFilter"));
         buildRule.executeTarget("scriptfilter");
-        assertContains("HELLO WORLD", getFileString(buildRule.getProject().getProperty("output") + "/scriptfilter"));
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/scriptfilter"),
+                containsString("HELLO WORLD"));
 
     }
 
     @Test
     public void testScriptFilter2() throws IOException {
-        Assume.assumeTrue("Project does not have 'testScriptFilter' target", buildRule.getProject().getTargets().contains("testScriptFilter"));
+        assumeThat("Project does not have 'testScriptFilter' target",
+                buildRule.getProject().getTargets(), hasKey("testScriptFilter"));
         buildRule.executeTarget("scriptfilter2");
-        assertContains("HELLO MOON", getFileString(buildRule.getProject().getProperty("output") + "/scriptfilter2"));
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/scriptfilter2"),
+                containsString("HELLO MOON"));
     }
 
     @Test
     public void testCustomTokenFilter() throws IOException {
         buildRule.executeTarget("customtokenfilter");
-        assertContains("Hello World", getFileString(buildRule.getProject().getProperty("output") + "/custom"));
+        assertThat(getFileString(buildRule.getProject().getProperty("output") + "/custom"),
+                containsString("Hello World"));
     }
 
     // ------------------------------------------------------
@@ -255,7 +271,7 @@ public class TokenFilterTest {
         Reader r = null;
         try {
             r = new FileReader(FILE_UTILS.resolveFile(buildRule.getProject().getBaseDir(),filename));
-            return  FileUtils.readFully(r);
+            return FileUtils.readFully(r);
         }
         finally {
             FileUtils.close(r);
@@ -265,7 +281,7 @@ public class TokenFilterTest {
 
     public static class Capitalize implements TokenFilter.Filter {
         public String filter(String token) {
-            if (token.length() == 0) {
+            if (token.isEmpty()) {
                 return token;
             }
             return token.substring(0, 1).toUpperCase() + token.substring(1);
