@@ -24,15 +24,16 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-
-import static org.apache.tools.ant.AntAssert.assertContains;
-import static org.junit.Assert.fail;
+import org.junit.rules.ExpectedException;
 
 public class EchoXMLTest {
 
     @Rule
     public final BuildFileRule buildRule = new BuildFileRule();
 
+    @Rule
+    public ExpectedException thrown = ExpectedException.none();
+
     @Before
     public void setUp() {
         buildRule.configureProject("src/etc/testcases/taskdefs/echoxml.xml");
@@ -50,22 +51,16 @@ public class EchoXMLTest {
 
     @Test
     public void testFail() {
-        try {
-            buildRule.executeTarget("testFail");
-            fail("BuildException expected: must fail");
-        } catch (BuildException ex) {
-            assertContains("${foo}=bar", ex.getMessage());
-        }
+        thrown.expect(BuildException.class);
+        thrown.expectMessage("${foo}=bar");
+        buildRule.executeTarget("testFail");
     }
 
     @Test
     public void testEmpty() {
-        try {
-            buildRule.executeTarget("testEmpty");
-            fail("BuildException expected: must fail");
-        } catch (BuildException ex) {
-            assertContains("No nested XML specified", ex.getMessage());
-        }
+        thrown.expect(BuildException.class);
+        thrown.expectMessage("No nested XML specified");
+        buildRule.executeTarget("testEmpty");
     }
 
 }
