@@ -24,8 +24,6 @@ import java.io.FileReader;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.IOException;
-import java.io.Reader;
-import java.util.Enumeration;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipFile;
 
@@ -33,17 +31,19 @@ import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.FileUtilities;
 import org.apache.tools.ant.util.FileUtils;
-import org.junit.After;
-import org.junit.Assume;
+import org.apache.tools.ant.util.StreamUtils;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 
-import static org.apache.tools.ant.AntAssert.assertContains;
+import static org.hamcrest.Matchers.containsString;
+import static org.hamcrest.Matchers.not;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertThat;
 import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeTrue;
 
 /**
  */
@@ -52,11 +52,11 @@ public class JarTest {
     @Rule
     public final BuildFileRule buildRule = new BuildFileRule();
 
+    @Rule
+    public ExpectedException thrown = ExpectedException.none();
+
     private static String tempJar = "tmp.jar";
     private static String tempDir = "jartmp/";
-    private Reader r1;
-    private Reader r2;
-
 
     @Before
     public void setUp() {
@@ -64,50 +64,31 @@ public class JarTest {
         buildRule.executeTarget("setUp");
     }
 
-    @After
-    public void tearDown() {
-        if (r1 != null) {
-            try {
-                r1.close();
-            } catch (IOException e) {
-            }
-        }
-        if (r2 != null) {
-            try {
-                r2.close();
-            } catch (IOException e) {
-            }
-        }
-    }
-
-    @Test
+    /**
+     * Expected failure due to required argument not specified
+     */
+    @Test(expected = BuildException.class)
     public void test1() {
-        try {
-            buildRule.executeTarget("test1");
-            fail("BuildException expected: required argument not specified");
-        } catch (BuildException ex) {
-            //TODO assert value
-        }
+        buildRule.executeTarget("test1");
+        // TODO assert exception message
     }
 
-    @Test
+    /**
+     * Expected failure due to nonexistent manifest file
+     */
+    @Test(expected = BuildException.class)
     public void test2() {
-        try {
-            buildRule.executeTarget("test2");
-            fail("BuildException expected: manifest file does not exist");
-        } catch (BuildException ex) {
-            //TODO assert value
-        }
+        buildRule.executeTarget("test2");
+        // TODO assert exception message
     }
 
-    @Test
+    /**
+     * Expected failure due to unrecognized whenempty attribute: format C: /y
+     */
+    @Test(expected = BuildException.class)
     public void test3() {
-        try {
-            buildRule.executeTarget("test3");
-            fail("BuildException expected: Unrecognized whenempty attribute: format C: /y");
-        } catch (BuildException ex) {
-            //TODO assert value
-        }
+        buildRule.executeTarget("test3");
+        // TODO assert exception message
     }
 
     private File getOutputDir() {
@@ -118,7 +99,6 @@ public class JarTest {
     public void test4() {
         buildRule.executeTarget("test4");
         File jarFile = new File(getOutputDir(), tempJar);
-
         assertTrue(jarFile.exists());
     }
 
@@ -137,7 +117,7 @@ public class JarTest {
         File jarFile = new File(getOutputDir(), tempJar);
 
         // move the modified date back a couple of seconds rather than delay the test on each run
-        Assume.assumeTrue(jarFile.setLastModified(jarFile.lastModified()
+        assumeTrue(jarFile.setLastModified(jarFile.lastModified()
                 - FileUtils.getFileUtils().getFileTimestampGranularity() * 3));
         long jarModifiedDate = jarFile.lastModified();
 
@@ -158,14 +138,12 @@ public class JarTest {
 
     @Test
     public void testRecreateWithoutUpdateNewerFile() {
-        testRecreate("testRecreateNewerFileSetup",
-                     "testRecreateWithoutUpdateNewerFile");
+        testRecreate("testRecreateNewerFileSetup", "testRecreateWithoutUpdateNewerFile");
     }
 
     @Test
     public void testRecreateWithUpdateNewerFile() {
-        testRecreate("testRecreateNewerFileSetup",
-                     "testRecreateWithUpdateNewerFile");
+        testRecreate("testRecreateNewerFileSetup", "testRecreateWithUpdateNewerFile");
     }
 
     private void testRecreate(String firstTarget, String secondTarget) {
@@ -181,22 +159,24 @@ public class JarTest {
         long jarModifiedDate = jarFile.lastModified();
         buildRule.executeTarget(secondTarget);
         jarFile = new File(getOutputDir(), tempJar);
-        assertTrue("jar has been recreated in " + secondTarget,
-                   jarModifiedDate < jarFile.lastModified());
+        assertTrue("jar has been recreated in " + secondTarget, jarModifiedDate < jarFile.lastModified());
     }
 
     @Test
-    public void testManifestStaysIntact()
-        throws IOException, ManifestException {
+    public void testManifestStaysIntact() throws IOException, ManifestException {
         buildRule.executeTarget("testManifestStaysIntact");
 
-        r1 = new FileReader(new File(getOutputDir(),
-                            tempDir + "manifest"));
-        r2 = new FileReader(new File(getOutputDir(),
-                tempDir + "META-INF/MANIFEST.MF"));
+        Manifest mf1;
+        try (FileReader r1 = new FileReader(new File(getOutputDir(), tempDir + "manifest"))) {
+            mf1 = new Manifest(r1);
+        }
+
+        Manifest mf2;
+        try (FileReader r2 = new FileReader(new File(getOutputDir(), tempDir
+                + "META-INF/MANIFEST.MF"))) {
+            mf2 = new Manifest(r2);
+        }
 
-        Manifest mf1 = new Manifest(r1);
-        Manifest mf2 = new Manifest(r2);
         assertEquals(mf1, mf2);
     }
 
@@ -222,26 +202,22 @@ public class JarTest {
 
     @Test
     public void testRecreateZipfilesetWithoutUpdateAdditionalFiles() {
-        testRecreate("test4",
-                     "testRecreateZipfilesetWithoutUpdateAdditionalFiles");
+        testRecreate("test4", "testRecreateZipfilesetWithoutUpdateAdditionalFiles");
     }
 
     @Test
     public void testRecreateZipfilesetWithUpdateAdditionalFiles() {
-        testRecreate("test4",
-                     "testRecreateZipfilesetWithUpdateAdditionalFiles");
+        testRecreate("test4", "testRecreateZipfilesetWithUpdateAdditionalFiles");
     }
 
     @Test
     public void testRecreateZipfilesetWithoutUpdateNewerFile() {
-        testRecreate("testRecreateNewerFileSetup",
-                     "testRecreateZipfilesetWithoutUpdateNewerFile");
+        testRecreate("testRecreateNewerFileSetup", "testRecreateZipfilesetWithoutUpdateNewerFile");
     }
 
     @Test
     public void testRecreateZipfilesetWithUpdateNewerFile() {
-        testRecreate("testRecreateNewerFileSetup",
-                     "testRecreateZipfilesetWithUpdateNewerFile");
+        testRecreate("testRecreateNewerFileSetup", "testRecreateZipfilesetWithUpdateNewerFile");
     }
 
     @Test
@@ -261,67 +237,50 @@ public class JarTest {
     // bugzilla report 10262
     @Test
     public void testNoDuplicateIndex() throws IOException {
-        ZipFile archive = null;
-        try {
-            buildRule.executeTarget("testIndexTests");
-            archive = new ZipFile(new File(getOutputDir(), tempJar));
-            Enumeration e = archive.entries();
-            int numberOfIndexLists = 0;
-            while (e.hasMoreElements()) {
-                ZipEntry ze = (ZipEntry) e.nextElement();
-                if (ze.getName().equals("META-INF/INDEX.LIST")) {
-                    numberOfIndexLists++;
-                }
-            }
-            assertEquals(1, numberOfIndexLists);
-        } finally {
-            if (archive != null) {
-                archive.close();
-            }
+        buildRule.executeTarget("testIndexTests");
+        try (ZipFile archive = new ZipFile(new File(getOutputDir(), tempJar))) {
+            assertEquals(1, StreamUtils.enumerationAsStream(archive.entries())
+                    .filter(ze -> ze.getName().equals("META-INF/INDEX.LIST")).count());
         }
     }
 
     // bugzilla report 16972
     @Test
     public void testRootFilesInIndex() throws IOException {
-        ZipFile archive = null;
-        try {
-            buildRule.executeTarget("testIndexTests");
-            archive = new ZipFile(new File(getOutputDir(), tempJar));
+        buildRule.executeTarget("testIndexTests");
+        try (ZipFile archive = new ZipFile(new File(getOutputDir(), tempJar))) {
             ZipEntry ze = archive.getEntry("META-INF/INDEX.LIST");
             InputStream is = archive.getInputStream(ze);
-            BufferedReader r = new BufferedReader(new InputStreamReader(is,
-                                                                        "UTF8"));
+            BufferedReader r = new BufferedReader(new InputStreamReader(is, "UTF8"));
             boolean foundSub = false;
             boolean foundSubFoo = false;
             boolean foundFoo = false;
 
             String line = r.readLine();
             while (line != null) {
-                if (line.equals("foo")) {
-                    foundFoo = true;
-                } else if (line.equals("sub")) {
-                    foundSub = true;
-                } else if (line.equals("sub/foo")) {
-                    foundSubFoo = true;
+                switch (line) {
+                    case "foo":
+                        foundFoo = true;
+                        break;
+                    case "sub":
+                        foundSub = true;
+                        break;
+                    case "sub/foo":
+                        foundSubFoo = true;
+                        break;
                 }
                 line = r.readLine();
             }
 
             assertTrue(foundSub);
-            assertTrue(!foundSubFoo);
+            assertFalse(foundSubFoo);
             assertTrue(foundFoo);
-        } finally {
-            if (archive != null) {
-                archive.close();
-            }
         }
     }
     @Test
     public void testManifestOnlyJar() {
-
         buildRule.executeTarget("testManifestOnlyJar");
-        assertContains("Building MANIFEST-only jar: ", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("Building MANIFEST-only jar: "));
         File manifestFile = new File(getOutputDir(), tempDir + "META-INF" + File.separator + "MANIFEST.MF");
         assertTrue(manifestFile.exists());
     }
@@ -333,44 +292,41 @@ public class JarTest {
 
     @Test
     public void testNoVersionInfoFail() {
-        try {
-            buildRule.executeTarget("testNoVersionInfoFail");
-            fail("BuildException expected: Manifest Implementation information missing.");
-        } catch (BuildException ex) {
-            assertContains("No Implementation-Title set.", ex.getMessage());
-        }
+        thrown.expect(BuildException.class);
+        thrown.expectMessage("No Implementation-Title set.");
+        buildRule.executeTarget("testNoVersionInfoFail");
     }
 
     @Test
     public void testNoVersionInfoIgnore() {
         buildRule.executeTarget("testNoVersionInfoIgnore");
-        assertTrue(buildRule.getFullLog().indexOf("No Implementation-Title set.") > -1);
-        assertTrue(buildRule.getFullLog().indexOf("No Implementation-Version set.") > -1);
-        assertTrue(buildRule.getFullLog().indexOf("No Implementation-Vendor set.") > -1);
+        assertThat(buildRule.getFullLog(), containsString("No Implementation-Title set."));
+        assertThat(buildRule.getFullLog(), containsString("No Implementation-Version set."));
+        assertThat(buildRule.getFullLog(), containsString("No Implementation-Vendor set."));
     }
 
     @Test
     public void testNoVersionInfoWarn() {
         buildRule.executeTarget("testNoVersionInfoWarn");
-        assertTrue(buildRule.getLog().indexOf("No Implementation-Title set.") > -1);
-        assertTrue(buildRule.getLog().indexOf("No Implementation-Version set.") > -1);
-        assertTrue(buildRule.getLog().indexOf("No Implementation-Vendor set.") > -1);
+        assertThat(buildRule.getLog(), containsString("No Implementation-Title set."));
+        assertThat(buildRule.getLog(), containsString("No Implementation-Version set."));
+        assertThat(buildRule.getLog(), containsString("No Implementation-Vendor set."));
     }
 
     @Test
     public void testNoVersionInfoNoStrict() {
         buildRule.executeTarget("testNoVersionInfoNoStrict");
-        assertFalse(buildRule.getLog().indexOf("No Implementation-Title set.") > -1);
-        assertFalse(buildRule.getLog().indexOf("No Implementation-Version set.") > -1);
-        assertFalse(buildRule.getLog().indexOf("No Implementation-Vendor set.") > -1);
+        assertThat(buildRule.getLog(), not(containsString("No Implementation-Title set.")));
+        assertThat(buildRule.getLog(), not(containsString("No Implementation-Version set.")));
+        assertThat(buildRule.getLog(), not(containsString("No Implementation-Vendor set.")));
     }
 
     @Test
     public void testHasVersionInfo() {
         buildRule.executeTarget("testHasVersionInfo");
-        assertFalse(buildRule.getLog().indexOf("No Implementation-Title set.") > -1);
-        assertFalse(buildRule.getLog().indexOf("No Implementation-Version set.") > -1);
-        assertFalse(buildRule.getLog().indexOf("No Implementation-Vendor set.") > -1);
+        assertThat(buildRule.getLog(), not(containsString("No Implementation-Title set.")));
+        assertThat(buildRule.getLog(), not(containsString("No Implementation-Version set.")));
+        assertThat(buildRule.getLog(), not(containsString("No Implementation-Vendor set.")));
     }
 
 }
