@@ -33,13 +33,11 @@ public class PathConvertTest {
     @Rule
     public final BuildFileRule buildRule = new BuildFileRule();
 
-    private static final String BUILD_PATH = "src/etc/testcases/taskdefs/";
     private static final String BUILD_FILENAME = "pathconvert.xml";
-    private static final String BUILD_FILE = BUILD_PATH + BUILD_FILENAME;
 
     @Before
     public void setUp() {
-        buildRule.configureProject(BUILD_FILE);
+        buildRule.configureProject("src/etc/testcases/taskdefs/" + BUILD_FILENAME);
     }
 
     @Test
