@@ -20,19 +20,19 @@ package org.apache.tools.ant.taskdefs;
 
 import java.lang.reflect.Method;
 
-import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.Task;
 import org.apache.tools.ant.TypeAdapter;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 
-import static org.apache.tools.ant.AntAssert.assertContains;
+import static org.hamcrest.Matchers.containsString;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
-
+import static org.junit.Assert.assertThat;
 
 /**
  */
@@ -41,6 +41,8 @@ public class TypeAdapterTest {
     @Rule
     public final BuildFileRule buildRule = new BuildFileRule();
 
+    @Rule
+    public ExpectedException thrown = ExpectedException.none();
 
     @Before
     public void setUp() {
@@ -50,41 +52,38 @@ public class TypeAdapterTest {
     @Test
     public void testTaskAdapter() {
         buildRule.executeTarget("taskadapter");
-		assertContains("MyExec called", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("MyExec called"));
     }
 
     @Test
     public void testRunAdapter() {
         buildRule.executeTarget("runadapter");
-		assertContains("MyRunnable called", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("MyRunnable called"));
     }
 
     @Test
     public void testRunAdapterError() {
-        try {
-            buildRule.executeTarget("runadaptererror");
-            fail("BuildException expected: no public run method");
-        } catch (BuildException ex) {
-            assertContains("No public run() method in", ex.getMessage());
-        }
+        thrown.expect(BuildException.class);
+        thrown.expectMessage("No public run() method in");
+        buildRule.executeTarget("runadaptererror");
     }
 
     @Test
     public void testDelay() {
         buildRule.executeTarget("delay");
-		assertContains("MyTask called", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("MyTask called"));
     }
 
     @Test
     public void testOnErrorReport() {
         buildRule.executeTarget("onerror.report");
-		assertContains("MyTaskNotPresent cannot be found", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("MyTaskNotPresent cannot be found"));
     }
 
     @Test
     public void testOnErrorIgnore() {
         buildRule.executeTarget("onerror.ignore");
-		assertEquals("", buildRule.getLog());
+        assertEquals("", buildRule.getLog());
     }
 
     public static class MyTask extends Task {
@@ -116,32 +115,27 @@ public class TypeAdapterTest {
     }
 
     public static class RunnableAdapter
-        extends Task implements TypeAdapter
-    {
+        extends Task implements TypeAdapter {
         private String execMethodName = "run";
         private Object proxy;
 
-        public Method getExecuteMethod(Class proxyClass) {
+        public Method getExecuteMethod(Class<?> proxyClass) {
             try {
                 Method execMethod = proxyClass.getMethod(execMethodName);
                 if (!Void.TYPE.equals(execMethod.getReturnType())) {
-                    String message =
-                        "return type of " + execMethodName + "() should be "
-                        + "void but was \"" + execMethod.getReturnType() +
-                        "\" in "
-                        + proxyClass;
+                    String message = "return type of " + execMethodName + "() should be "
+                            + "void but was \"" + execMethod.getReturnType()
+                            + "\" in " + proxyClass;
                     log(message, Project.MSG_WARN);
                 }
                 return execMethod;
             } catch (NoSuchMethodException e) {
-                String message = "No public "+ execMethodName +
-                    "() method in "
-                    + proxyClass;
+                String message = "No public " + execMethodName + "() method in " + proxyClass;
                 log(message, Project.MSG_ERR);
                 throw new BuildException(message);
             }
         }
-        public void checkProxyClass(Class proxyClass) {
+        public void checkProxyClass(Class<?> proxyClass) {
             getExecuteMethod(proxyClass);
         }
 
