@@ -18,15 +18,15 @@
 
 package org.apache.tools.ant.taskdefs;
 
+import static org.junit.Assert.assertEquals;
+
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.Task;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import org.junit.rules.ExpectedException;
 
 
 public class XmlnsTest {
@@ -34,6 +34,9 @@ public class XmlnsTest {
     @Rule
     public final BuildFileRule buildRule = new BuildFileRule();
 
+    @Rule
+    public ExpectedException thrown = ExpectedException.none();
+
     @Before
     public void setUp() {
         buildRule.configureProject("src/etc/testcases/taskdefs/xmlns.xml");
@@ -42,41 +45,38 @@ public class XmlnsTest {
     @Test
     public void testXmlns() {
         buildRule.executeTarget("xmlns");
-		assertEquals("MyTask called", buildRule.getLog());
+        assertEquals("MyTask called", buildRule.getLog());
     }
 
     @Test
     public void testXmlnsFile() {
         buildRule.executeTarget("xmlns.file");
-		assertEquals("MyTask called", buildRule.getLog());
+        assertEquals("MyTask called", buildRule.getLog());
     }
 
     @Test
     public void testCore() {
         buildRule.executeTarget("core");
-		assertEquals("MyTask called", buildRule.getLog());
+        assertEquals("MyTask called", buildRule.getLog());
     }
 
     @Test
     public void testExcluded() {
-        try {
-            buildRule.executeTarget("excluded");
-            fail("BuildException expected: excluded uri");
-        } catch (BuildException ex) {
-            assertEquals("Attempt to use a reserved URI ant:notallowed", ex.getMessage());
-        }
+        thrown.expect(BuildException.class);
+        thrown.expectMessage("Attempt to use a reserved URI ant:notallowed");
+        buildRule.executeTarget("excluded");
     }
 
     @Test
     public void testOther() {
         buildRule.executeTarget("other");
-		assertEquals("a message", buildRule.getLog());
+        assertEquals("a message", buildRule.getLog());
     }
 
     @Test
     public void testNsAttributes() {
         buildRule.executeTarget("ns.attributes");
-		assertEquals("hello world", buildRule.getLog());
+        assertEquals("hello world", buildRule.getLog());
     }
 
     public static class MyTask extends Task {
@@ -86,4 +86,3 @@ public class XmlnsTest {
     }
 
 }
-
