@@ -39,11 +39,9 @@ public class TranslateTest {
     @Rule
     public final BuildFileRule buildRule = new BuildFileRule();
 
-    static private final int BUF_SIZE = 32768;
-
-    private final static String TASKDEFS_DIR = "src/etc/testcases/taskdefs/optional/i18n/translate";
-
+    private static final int BUF_SIZE = 32768;
 
+    private static final String TASKDEFS_DIR = "src/etc/testcases/taskdefs/optional/i18n/translate";
 
     @Before
     public void setUp() {
@@ -53,9 +51,11 @@ public class TranslateTest {
     @Test
     public void test1() throws IOException {
         buildRule.executeTarget("test1");
-        assertTrue("translation of "+ TASKDEFS_DIR + "/input/template.txt",compareFiles(new File(buildRule.getProject().getBaseDir(), "expected/de/template.txt"),
-                new File(buildRule.getOutputDir(), "de/template.txt")));
+        assertTrue("translation of " + TASKDEFS_DIR + "/input/template.txt",
+                compareFiles(new File(buildRule.getProject().getBaseDir(), "expected/de/template.txt"),
+                        new File(buildRule.getOutputDir(), "de/template.txt")));
     }
+
     private boolean compareFiles(File file1, File file2) throws IOException {
         if (!file1.exists() || !file2.exists()) {
             return false;
@@ -69,19 +69,18 @@ public class TranslateTest {
         byte[] buffer1 = new byte[BUF_SIZE];
         byte[] buffer2 = new byte[BUF_SIZE];
 
-        FileInputStream fis1 = new FileInputStream(file1);
-        FileInputStream fis2 = new FileInputStream(file2);
-        int index = 0;
-        int read = 0;
-        while ((read = fis1.read(buffer1)) != -1) {
-            fis2.read(buffer2);
-            for (int i = 0; i < read; ++i, ++index) {
-                if (buffer1[i] != buffer2[i]) {
-                    return false;
+        try (FileInputStream fis1 = new FileInputStream(file1);
+             FileInputStream fis2 = new FileInputStream(file2)) {
+            int read = 0;
+            while ((read = fis1.read(buffer1)) != -1) {
+                fis2.read(buffer2);
+                for (int i = 0; i < read; ++i) {
+                    if (buffer1[i] != buffer2[i]) {
+                        return false;
+                    }
                 }
             }
         }
         return true;
     }
 }
-
