@@ -17,14 +17,16 @@
  */
 package org.apache.tools.ant.taskdefs.optional.junit;
 
+import static org.hamcrest.Matchers.containsString;
+import static org.hamcrest.Matchers.not;
+import static org.hamcrest.Matchers.startsWith;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertThat;
 import static org.junit.Assert.assertTrue;
-
-import static org.apache.tools.ant.AntAssert.assertNotContains;
-import static org.apache.tools.ant.AntAssert.assertContains;
+import static org.junit.Assume.assumeTrue;
 
 import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
@@ -52,7 +54,6 @@ import org.apache.tools.ant.taskdefs.launcher.CommandLauncher;
 import org.apache.tools.ant.types.Path;
 import org.apache.tools.ant.util.JavaEnvUtils;
 import org.apache.tools.ant.util.LoaderUtils;
-import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -97,7 +98,7 @@ public class JUnitTaskTest {
     }
 
     @Test
-    public void testNonForkedCapture() throws IOException {
+    public void testNonForkedCapture() {
         buildRule.executeTarget("capture");
         assertNoPrint(buildRule.getLog(), "log");
         assertNoPrint(buildRule.getFullLog(), "debug log");
@@ -140,7 +141,7 @@ public class JUnitTaskTest {
         if (JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_1_5)) {
             try {
                 Class<?> clazz = Class.forName("junit.framework.JUnit4TestAdapter");
-                Assume.assumeFalse("Skipping test since it fails with JUnit 4", clazz != null);
+                assumeTrue("Skipping test since it fails with JUnit 4", clazz == null);
             } catch (ClassNotFoundException e) {
                 // OK, this is JUnit3, can run test
             }
@@ -179,26 +180,26 @@ public class JUnitTaskTest {
                    collectorFile.exists());
         // the passing test cases
         buildRule.executeTarget("A.test01");
-        assertContains("1st run: should run A.test01", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run A.test01"));
         buildRule.executeTarget("B.test05");
-        assertContains("1st run: should run B.test05", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run B.test05"));
         buildRule.executeTarget("B.test06");
-        assertContains("1st run: should run B.test06", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run B.test06"));
         buildRule.executeTarget("C.test07");
-        assertContains("1st run: should run C.test07", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run C.test07"));
         buildRule.executeTarget("C.test08");
-        assertContains("1st run: should run C.test08", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run C.test08"));
         buildRule.executeTarget("C.test09");
-        assertContains("1st run: should run C.test09", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run C.test09"));
         // the failing test cases
         buildRule.executeTarget("A.test02");
-        assertContains("1st run: should run A.test02", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run A.test02"));
         buildRule.executeTarget("A.test03");
-        assertContains("1st run: should run A.test03", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run A.test03"));
         buildRule.executeTarget("B.test04");
-        assertContains("1st run: should run B.test04", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run B.test04"));
         buildRule.executeTarget("D.test10");
-        assertContains("1st run: should run D.test10", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run D.test10"));
 
 
         // 2nd junit run: should do only failing tests
@@ -208,26 +209,26 @@ public class JUnitTaskTest {
                    collectorFile.exists());
         // the passing test cases
         buildRule.executeTarget("A.test01");
-        assertNotContains("2nd run: should not run A.test01", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run A.test01")));
         buildRule.executeTarget("B.test05");
-        assertNotContains("2nd run: should not run A.test05", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run A.test05")));
         buildRule.executeTarget("B.test06");
-        assertNotContains("2nd run: should not run B.test06", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run B.test06")));
         buildRule.executeTarget("C.test07");
-        assertNotContains("2nd run: should not run C.test07", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run C.test07")));
         buildRule.executeTarget("C.test08");
-        assertNotContains("2nd run: should not run C.test08", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run C.test08")));
         buildRule.executeTarget("C.test09");
-        assertNotContains("2nd run: should not run C.test09", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run C.test09")));
         // the failing test cases
         buildRule.executeTarget("A.test02");
-        assertContains("2nd run: should run A.test02", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("2nd run: should run A.test02"));
         buildRule.executeTarget("A.test03");
-        assertContains("2nd run: should run A.test03", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("2nd run: should run A.test03"));
         buildRule.executeTarget("B.test04");
-        assertContains("2nd run: should run B.test04", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("2nd run: should run B.test04"));
         buildRule.executeTarget("D.test10");
-        assertContains("2nd run: should run D.test10", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("2nd run: should run D.test10"));
 
 
         // "fix" errors in class A
@@ -239,13 +240,13 @@ public class JUnitTaskTest {
                    + "' should exist after the 3rd run.",
                    collectorFile.exists());
         buildRule.executeTarget("A.test02");
-        assertContains("3rd run: should run A.test02", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("3rd run: should run A.test02"));
         buildRule.executeTarget("A.test03");
-        assertContains("3rd run: should run A.test03", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("3rd run: should run A.test03"));
         buildRule.executeTarget("B.test04");
-        assertContains("3rd run: should run B.test04", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("3rd run: should run B.test04"));
         buildRule.executeTarget("D.test10");
-        assertContains("3rd run: should run D.test10", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("3rd run: should run D.test10"));
 
 
         // 4rd run: two running tests with errors
@@ -253,13 +254,15 @@ public class JUnitTaskTest {
         assertTrue("The collector file '" + collectorFile.getAbsolutePath()
                    + "' should exist after the 4th run.",
                    collectorFile.exists());
-        //TODO: these two statements fail
-        //buildRule.executeTarget("A.test02");assertNotContains("4th run: should not run A.test02", buildRule.getOutput());
-        //buildRule.executeTarget("A.test03");assertNotContains("4th run: should not run A.test03", buildRule.getOutput());
+        //TODO: these statements fail
+        //buildRule.executeTarget("A.test02");
+        //assertThat(buildRule.getOutput(), not(containsString("4th run: should not run A.test02")));
+        //buildRule.executeTarget("A.test03");
+        //assertThat(buildRule.getOutput(), not(containsString("4th run: should not run A.test03")));
         buildRule.executeTarget("B.test04");
-        assertContains("4th run: should run B.test04", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("4th run: should run B.test04"));
         buildRule.executeTarget("D.test10");
-        assertContains("4th run: should run D.test10", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("4th run: should run D.test10"));
 
     }
 
@@ -272,16 +275,16 @@ public class JUnitTaskTest {
     @Test
     public void testMultilineAssertsNoFork() {
         buildRule.executeTarget("testMultilineAssertsNoFork");
-        assertNotContains("messaged up", buildRule.getLog());
-        assertNotContains("crashed)", buildRule.getLog());
+        assertThat(buildRule.getLog(), not(containsString("messaged up")));
+        assertThat(buildRule.getLog(), not(containsString("crashed)")));
     }
 
     // Bugzilla Issue 45411
     @Test
     public void testMultilineAssertsFork() {
         buildRule.executeTarget("testMultilineAssertsFork");
-        assertNotContains("messaged up", buildRule.getLog());
-        assertNotContains("crashed)", buildRule.getLog());
+        assertThat(buildRule.getLog(), not(containsString("messaged up")));
+        assertThat(buildRule.getLog(), not(containsString("crashed)")));
     }
 
     private void assertResultFilesExist(String target, String extension) {
@@ -301,46 +304,37 @@ public class JUnitTaskTest {
     }
 
     private void assertNoPrint(String result, String where) {
-        assertNotContains(where + " '" + result + "' must not contain print statement",
-                   "print to System.", result);
+        assertThat(where + " '" + result + "' must not contain print statement",
+                result, not(containsString("print to System.")));
     }
 
     private void assertOutput() throws IOException {
-        FileReader inner = new FileReader(new File(buildRule.getOutputDir(),
-                                          "testlog.txt"));
-        BufferedReader reader = new BufferedReader(inner);
-        try {
+        FileReader inner = new FileReader(new File(buildRule.getOutputDir(), "testlog.txt"));
+        try (BufferedReader reader = new BufferedReader(inner)) {
             String line = reader.readLine();
-            assertEquals("Testsuite: org.apache.tools.ant.taskdefs.optional.junit.Printer",
-                         line);
+            assertEquals("Testsuite: org.apache.tools.ant.taskdefs.optional.junit.Printer", line);
             line = reader.readLine();
             assertNotNull(line);
-            assertTrue(line.startsWith("Tests run: 1, Failures: 0, Errors: 0, Skipped: 0, Time elapsed:"));
+            assertThat(line, startsWith("Tests run: 1, Failures: 0, Errors: 0, Skipped: 0, Time elapsed:"));
             line = reader.readLine();
-            assertEquals("------------- Standard Output ---------------",
-                         line);
+            assertEquals("------------- Standard Output ---------------", line);
             assertPrint(reader.readLine(), "static", "out");
             assertPrint(reader.readLine(), "constructor", "out");
             assertPrint(reader.readLine(), "method", "out");
             line = reader.readLine();
-            assertEquals("------------- ---------------- ---------------",
-                         line);
+            assertEquals("------------- ---------------- ---------------", line);
             line = reader.readLine();
-            assertEquals("------------- Standard Error -----------------",
-                         line);
+            assertEquals("------------- Standard Error -----------------", line);
             assertPrint(reader.readLine(), "static", "err");
             assertPrint(reader.readLine(), "constructor", "err");
             assertPrint(reader.readLine(), "method", "err");
             line = reader.readLine();
-            assertEquals("------------- ---------------- ---------------",
-                         line);
+            assertEquals("------------- ---------------- ---------------", line);
             line = reader.readLine();
             assertEquals("", line);
             line = reader.readLine();
             assertNotNull(line);
-            assertTrue(line.startsWith("Testcase: testNoCrash took "));
-        } finally {
-            inner.close();
+            assertThat(line, startsWith("Testcase: testNoCrash took "));
         }
     }
 
@@ -385,12 +379,12 @@ public class JUnitTaskTest {
     }
 
     @Test
-    public void testTestMethods() throws Exception {
+    public void testTestMethods() {
         buildRule.executeTarget("testTestMethods");
     }
 
     @Test
-    public void testNonTestsSkipped() throws Exception {
+    public void testNonTestsSkipped() {
 
         buildRule.executeTarget("testNonTests");
         assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.NonTestMissed.xml",
@@ -577,13 +571,41 @@ public class JUnitTaskTest {
         }
     }
 
+    private void setupCheckDuplicateTest() {
+        final String projectResourceName =
+                LoaderUtils.classNameToResource(Project.class.getName());
+        final File antclasses = LoaderUtils.getResourceSource(
+                Project.class.getClassLoader(), projectResourceName);
+        final String testResourceName =
+                LoaderUtils.classNameToResource(junit.framework.Test.class.getName());
+        final File junitJar = LoaderUtils.getResourceSource(
+                Project.class.getClassLoader(), testResourceName);
+        buildRule.getProject().setProperty("antclasses", antclasses.getAbsolutePath());
+        buildRule.getProject().setProperty("junitjar", junitJar.getAbsolutePath());
+    }
+
+    @Test
+    public void testCheckDuplicateAntJar() {
+        setupCheckDuplicateTest();
+        buildRule.executeTarget("testCheckForkedPath");
+        assertThat("Expecting the warning about the duplicate ant jar", buildRule.getLog(),
+                containsString("WARNING: multiple versions of ant detected in path for junit"));
+    }
+
+    @Test
+    public void testCheckNonDuplicateAntJar() {
+        setupCheckDuplicateTest();
+        buildRule.getProject().setProperty("includeantruntime", "no");
+        buildRule.executeTarget("testCheckForkedPath");
+        assertThat("Unexpected warning about the duplicate ant jar", buildRule.getLog(),
+                not(containsString("WARNING: multiple versions of ant detected in path for junit")));
+    }
+
     private void delete(File f) {
         if (f.isDirectory()) {
             final File[] clds = f.listFiles();
             if (clds != null) {
-                for (File cld : clds) {
-                    delete(cld);
-                }
+                Arrays.stream(clds).forEach(this::delete);
             }
         }
         f.delete();
