@@ -18,7 +18,6 @@
 
 package org.apache.tools.ant.types;
 
-import org.apache.tools.ant.AntAssert;
 import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Project;
@@ -27,14 +26,19 @@ import org.apache.tools.ant.taskdefs.condition.Condition;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 
-import static org.junit.Assert.fail;
+import static org.hamcrest.Matchers.containsString;
+import static org.junit.Assert.assertThat;
 
 public class AddTypeTest {
 
     @Rule
     public BuildFileRule buildRule = new BuildFileRule();
 
+    @Rule
+    public ExpectedException thrown = ExpectedException.none();
+
     @Before
     public void setUp() {
         buildRule.configureProject("src/etc/testcases/types/addtype.xml");
@@ -63,71 +67,65 @@ public class AddTypeTest {
     @Test
     public void testNestedA() {
         buildRule.executeTarget("nested.a");
-        AntAssert.assertContains("add A called", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("add A called"));
     }
 
     @Test
     public void testNestedB() {
         buildRule.executeTarget("nested.b");
-         AntAssert.assertContains("add B called", buildRule.getLog());
+         assertThat(buildRule.getLog(), containsString("add B called"));
     }
 
     @Test
     public void testNestedC() {
         buildRule.executeTarget("nested.c");
-        AntAssert.assertContains("add C called", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("add C called"));
     }
 
     @Test
     public void testNestedAB() {
-        try {
-            buildRule.executeTarget("nested.ab");
-            fail("Build exception expected: Should have got ambiguous");
-        } catch (BuildException ex) {
-            AntAssert.assertContains("ambiguous", ex.getMessage());
-        }
+        thrown.expect(BuildException.class);
+        thrown.expectMessage("ambiguous");
+        buildRule.executeTarget("nested.ab");
     }
 
     @Test
     public void testConditionType() {
         buildRule.executeTarget("condition.type");
-        AntAssert.assertContains("beforeafter", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("beforeafter"));
     }
 
     @Test
     public void testConditionTask() {
         buildRule.executeTarget("condition.task");
-        AntAssert.assertContains("My Condition execution", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("My Condition execution"));
     }
 
     @Test
     public void testConditionConditionType() {
         buildRule.executeTarget("condition.condition.type");
-        AntAssert.assertContains("My Condition eval", buildRule.getLog());
+        assertThat(buildRule.getLog(), containsString("My Condition eval"));
     }
 
     @Test
     public void testConditionConditionTask() {
-        try {
-            buildRule.executeTarget("condition.condition.task");
-            fail("Build exception expected: Task masking condition");
-        } catch (BuildException ex) {
-             AntAssert.assertContains("doesn't support the nested", ex.getMessage());
-        }
+        thrown.expect(BuildException.class);
+        thrown.expectMessage("doesn't support the nested");
+        buildRule.executeTarget("condition.condition.task");
     }
 
     @Test
     public void testAddConfigured() {
         buildRule.executeTarget("myaddconfigured");
-        AntAssert.assertContains("value is Value Setexecute: value is Value Set",
-                buildRule.getLog());
+        assertThat(buildRule.getLog(),
+                containsString("value is Value Setexecute: value is Value Set"));
     }
 
     @Test
     public void testAddConfiguredValue() {
         buildRule.executeTarget("myaddconfiguredvalue");
-        AntAssert.assertContains("value is Value Setexecute: value is Value Set",
-                buildRule.getLog());
+        assertThat(buildRule.getLog(),
+                containsString("value is Value Setexecute: value is Value Set"));
     }
 
     @Test
