@@ -23,6 +23,9 @@ import org.apache.tools.ant.Task;
 import org.apache.tools.ant.types.Mapper;
 import org.apache.tools.ant.util.FileNameMapper;
 
+import java.util.Arrays;
+import java.util.stream.Collectors;
+
 /**
  * This is a test task to show the result of a mapper
  * on a specific input.
@@ -80,14 +83,7 @@ public class MapperResult extends Task {
         if (result == null) {
             flattened = NULL_MAPPER_RESULT;
         } else {
-            StringBuilder b = new StringBuilder();
-            for (int i = 0; i < result.length; ++i) {
-                if (i != 0) {
-                    b.append("|");
-                }
-                b.append(result[i]);
-            }
-            flattened = b.toString();
+            flattened = Arrays.stream(result).collect(Collectors.joining("|"));
         }
         if (!flattened.equals(output)) {
             throw new BuildException(failMessage + " got " + flattened + " expected " + output);
