@@ -18,13 +18,14 @@
 package org.apache.tools.ant.types.resources;
 
 import java.io.File;
+import java.io.IOException;
 
 import org.apache.tools.ant.Project;
-
 import org.junit.Before;
 import org.junit.Test;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
 
 /**
  * Test Java API of {@link FileResource}.
@@ -34,8 +35,9 @@ public class FileResourceTest {
     private File root;
 
     @Before
-    public void setUp() {
-        root = new File(System.getProperty("root"));
+    public void setUp() throws IOException {
+        root = (System.getProperty("root") == null) ? new File(".").getCanonicalFile()
+                : new File(System.getProperty("root"));
     }
 
     @Test
@@ -119,4 +121,18 @@ public class FileResourceTest {
         assertEquals(root, parentSibling.getBaseDir());
         assertEquals("bar", parentSibling.getName());
     }
+
+    @Test
+    public void testEqualsUsesFiles() {
+        FileResource f1 = new FileResource(new File(root, "foo/a"));
+        FileResource f2 = new FileResource(new File(root + "/foo"), "a");
+        assertEquals(f1, f2);
+    }
+
+    @Test
+    public void testEqualsUsesRelativeNames() {
+        FileResource f1 = new FileResource(root, "foo/a");
+        FileResource f2 = new FileResource(new File(root + "/foo"), "a");
+        assertNotEquals(f1, f2);
+    }
 }
