@@ -28,7 +28,6 @@ import org.junit.Test;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
 
 public class LazyResourceCollectionTest {
 
@@ -77,7 +76,7 @@ public class LazyResourceCollectionTest {
     }
 
     @Test
-    public void testLazyLoading() throws Exception {
+    public void testLazyLoading() {
         StringResourceCollection collectionTest = new StringResourceCollection();
         LazyResourceCollectionWrapper lazyCollection = new LazyResourceCollectionWrapper();
         lazyCollection.add(collectionTest);
@@ -102,13 +101,19 @@ public class LazyResourceCollectionTest {
         assertOneCreatedIterator(collectionTest);
         assertEquals("Iterating 3 times load more than 3 resources", 3,
             stringResourceIterator.cursor);
+    }
 
-        try {
-            it.next();
-            fail("NoSuchElementException should have been raised");
-        } catch (NoSuchElementException e) {
-            // ok
-        }
+    @Test(expected = NoSuchElementException.class)
+    public void testLazyLoadingFailsOnceWrappedCollectionIsExhausted() {
+        StringResourceCollection collectionTest = new StringResourceCollection();
+        LazyResourceCollectionWrapper lazyCollection = new LazyResourceCollectionWrapper();
+        lazyCollection.add(collectionTest);
+
+        Iterator<Resource> it = lazyCollection.iterator();
+        it.next();
+        it.next();
+        it.next();
+        it.next();
     }
 
     private void assertOneCreatedIterator(
@@ -118,7 +123,7 @@ public class LazyResourceCollectionTest {
     }
 
     @Test
-    public void testCaching() throws Exception {
+    public void testCaching() {
         StringResourceCollection collectionTest = new StringResourceCollection();
         LazyResourceCollectionWrapper lazyCollection = new LazyResourceCollectionWrapper();
         lazyCollection.add(collectionTest);
@@ -159,19 +164,32 @@ public class LazyResourceCollectionTest {
         assertEquals(
             "The first iterator did not lookup in the cache for a resource", 3,
             stringResourceIterator.cursor);
+    }
 
+    @Test(expected = NoSuchElementException.class)
+    public void testCachingFailsOnceWrappedCollectionIsExhausted() {
+        StringResourceCollection collectionTest = new StringResourceCollection();
+        LazyResourceCollectionWrapper lazyCollection = new LazyResourceCollectionWrapper();
+        lazyCollection.add(collectionTest);
+
+        Iterator<Resource> it1 = lazyCollection.iterator();
+        Iterator<Resource> it2 = lazyCollection.iterator();
+
+        it1.next();
+        it2.next();
+        it2.next();
+        it1.next();
+        it2.next();
+        it1.next();
+
+        // next() must throw the expected NoSuchElementException;
+        // if that does not happen, assertions throw the unexpected Assertion error
         try {
             it1.next();
-            fail("NoSuchElementException should have been raised");
-        } catch (NoSuchElementException e) {
-            // ok
-        }
-
-        try {
+            assertTrue(it1.hasNext());
+        } finally {
             it2.next();
-            fail("NoSuchElementException should have been raised");
-        } catch (NoSuchElementException e) {
-            // ok
+            assertTrue(it2.hasNext());
         }
     }
 
