@@ -26,6 +26,7 @@ import java.io.IOException;
 import java.io.StringWriter;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
 /**
@@ -41,9 +42,9 @@ public class DOMElementWriterTest {
         assertTrue("&#20;", w.isReference("&#20;"));
         assertTrue("&#x20;", w.isReference("&#x20;"));
         assertTrue("&#xA0;", w.isReference("&#xA0;"));
-        assertTrue("&#A0;", !w.isReference("&#A0;"));
-        assertTrue("20;", !w.isReference("20;"));
-        assertTrue("&#20", !w.isReference("&#20"));
+        assertFalse("&#A0;", w.isReference("&#A0;"));
+        assertFalse("20;", w.isReference("20;"));
+        assertFalse("&#20", w.isReference("&#20"));
         assertTrue("&quot;", w.isReference("&quot;"));
         assertTrue("&apos;", w.isReference("&apos;"));
         assertTrue("&gt;", w.isReference("&gt;"));
@@ -99,8 +100,7 @@ public class DOMElementWriterTest {
         StringWriter sw = new StringWriter();
         DOMElementWriter w = new DOMElementWriter();
         w.write(root, sw, 0, "  ");
-        assertEquals("<root foo=\"bar&#xa;baz\" />" + StringUtils.LINE_SEP,
-                     sw.toString());
+        assertEquals(String.format("<root foo=\"bar&#xa;baz\" />%n"), sw.toString());
     }
 
     @Test
@@ -111,18 +111,18 @@ public class DOMElementWriterTest {
 
     @Test
     public void testIsLegalCharacter() {
-        assertTrue("0x00", !w.isLegalCharacter('\u0000'));
+        assertFalse("0x00", w.isLegalCharacter('\u0000'));
         assertTrue("0x09", w.isLegalCharacter('\t'));
         assertTrue("0x0A", w.isLegalCharacter('\n'));
         assertTrue("0x0C", w.isLegalCharacter('\r'));
-        assertTrue("0x1F", !w.isLegalCharacter('\u001F'));
+        assertFalse("0x1F", w.isLegalCharacter('\u001F'));
         assertTrue("0x20", w.isLegalCharacter('\u0020'));
         assertTrue("0xD7FF", w.isLegalCharacter('\uD7FF'));
-        assertTrue("0xD800", !w.isLegalCharacter('\uD800'));
-        assertTrue("0xDFFF", !w.isLegalCharacter('\uDFFF'));
+        assertFalse("0xD800", w.isLegalCharacter('\uD800'));
+        assertFalse("0xDFFF", w.isLegalCharacter('\uDFFF'));
         assertTrue("0xE000", w.isLegalCharacter('\uE000'));
         assertTrue("0xFFFD", w.isLegalCharacter('\uFFFD'));
-        assertTrue("0xFFFE", !w.isLegalCharacter('\uFFFE'));
+        assertFalse("0xFFFE", w.isLegalCharacter('\uFFFE'));
     }
 
     @Test
@@ -146,11 +146,8 @@ public class DOMElementWriterTest {
         StringWriter sw = new StringWriter();
         DOMElementWriter w = new DOMElementWriter();
         w.write(root, sw, 0, "  ");
-        assertEquals("<root>" + StringUtils.LINE_SEP
-                     + "  <textElement>content</textElement>"
-                     + StringUtils.LINE_SEP
-                     + "</root>" + StringUtils.LINE_SEP,
-                     sw.toString());
+        assertEquals(String.format("<root>%n  <textElement>content</textElement>%n</root>%n"),
+                sw.toString());
     }
 
     @Test
@@ -162,11 +159,8 @@ public class DOMElementWriterTest {
         StringWriter sw = new StringWriter();
         DOMElementWriter w = new DOMElementWriter();
         w.write(root, sw, 0, "  ");
-        assertEquals("<root>" + StringUtils.LINE_SEP
-                     + "  <cdataElement><![CDATA[content]]></cdataElement>"
-                     + StringUtils.LINE_SEP
-                     + "</root>" + StringUtils.LINE_SEP,
-                     sw.toString());
+        assertEquals(String.format("<root>%n  <cdataElement><![CDATA[content]]></cdataElement>%n"
+                        + "</root>%n"), sw.toString());
     }
 
     @Test
@@ -178,12 +172,7 @@ public class DOMElementWriterTest {
         StringWriter sw = new StringWriter();
         DOMElementWriter w = new DOMElementWriter();
         w.write(root, sw, 0, "  ");
-        assertEquals("<root>" + StringUtils.LINE_SEP
-                     //                     + "  <emptyElement></emptyElement>"
-                     + "  <emptyElement />"
-                     + StringUtils.LINE_SEP
-                     + "</root>" + StringUtils.LINE_SEP,
-                     sw.toString());
+        assertEquals(String.format("<root>%n  <emptyElement />%n</root>%n"), sw.toString());
     }
 
     @Test
@@ -195,8 +184,7 @@ public class DOMElementWriterTest {
         StringWriter sw = new StringWriter();
         DOMElementWriter w = new DOMElementWriter();
         w.write(root, sw, 0, "  ");
-        assertEquals("<root bar=\"baz\" />"
-                     + StringUtils.LINE_SEP, sw.toString());
+        assertEquals(String.format("<root bar=\"baz\" />%n"), sw.toString());
     }
 
     @Test
@@ -206,13 +194,10 @@ public class DOMElementWriterTest {
         root.setAttributeNS("urn:foo2", "bar", "baz");
 
         StringWriter sw = new StringWriter();
-        DOMElementWriter w =
-            new DOMElementWriter(false,
-                                 DOMElementWriter.XmlNamespacePolicy
-                                 .ONLY_QUALIFY_ELEMENTS);
+        DOMElementWriter w = new DOMElementWriter(false,
+                DOMElementWriter.XmlNamespacePolicy.ONLY_QUALIFY_ELEMENTS);
         w.write(root, sw, 0, "  ");
-        assertEquals("<root bar=\"baz\" xmlns=\"urn:foo\" />"
-                     + StringUtils.LINE_SEP, sw.toString());
+        assertEquals(String.format("<root bar=\"baz\" xmlns=\"urn:foo\" />%n"), sw.toString());
     }
 
     @Test
@@ -222,14 +207,11 @@ public class DOMElementWriterTest {
         root.setAttributeNS("urn:foo2", "bar", "baz");
 
         StringWriter sw = new StringWriter();
-        DOMElementWriter w =
-            new DOMElementWriter(false,
-                                 DOMElementWriter.XmlNamespacePolicy
-                                 .QUALIFY_ALL);
+        DOMElementWriter w = new DOMElementWriter(false,
+                DOMElementWriter.XmlNamespacePolicy.QUALIFY_ALL);
         w.write(root, sw, 0, "  ");
-        assertEquals("<root ns0:bar=\"baz\" xmlns=\"urn:foo\""
-                     + " xmlns:ns0=\"urn:foo2\" />"
-                     + StringUtils.LINE_SEP, sw.toString());
+        assertEquals(String.format("<root ns0:bar=\"baz\" xmlns=\"urn:foo\""
+                     + " xmlns:ns0=\"urn:foo2\" />%n"), sw.toString());
     }
 
     @Test
@@ -239,11 +221,11 @@ public class DOMElementWriterTest {
         root.setAttributeNS("urn:foo2", "bar", "baz");
 
         StringWriter sw = new StringWriter();
-        DOMElementWriter w =
-            new DOMElementWriter(false, new DOMElementWriter.XmlNamespacePolicy(false, true));
+        DOMElementWriter w = new DOMElementWriter(false,
+                new DOMElementWriter.XmlNamespacePolicy(false, true));
         w.write(root, sw, 0, "  ");
-        assertEquals("<root ns0:bar=\"baz\" xmlns:ns0=\"urn:foo2\" />"
-                     + StringUtils.LINE_SEP, sw.toString());
+        assertEquals(String.format("<root ns0:bar=\"baz\" xmlns:ns0=\"urn:foo2\" />%n"),
+                sw.toString());
     }
 
     @Test
@@ -253,17 +235,11 @@ public class DOMElementWriterTest {
         Element child = d.createElementNS("urn:foo", "child");
         root.appendChild(child);
         StringWriter sw = new StringWriter();
-        DOMElementWriter w =
-            new DOMElementWriter(false,
-                                 DOMElementWriter.XmlNamespacePolicy
-                                 .ONLY_QUALIFY_ELEMENTS);
+        DOMElementWriter w = new DOMElementWriter(false,
+                DOMElementWriter.XmlNamespacePolicy.ONLY_QUALIFY_ELEMENTS);
         w.write(root, sw, 0, "  ");
-        assertEquals("<root xmlns=\"urn:foo\">"
-                     + StringUtils.LINE_SEP
-                     + "  <child />"
-                     + StringUtils.LINE_SEP
-                     + "</root>"
-                     + StringUtils.LINE_SEP, sw.toString());
+        assertEquals(String.format("<root xmlns=\"urn:foo\">%n  <child />%n</root>%n"),
+                sw.toString());
     }
 
     @Test
@@ -279,24 +255,15 @@ public class DOMElementWriterTest {
         Element child3 = d.createElementNS("urn:foo2", "child");
         root.appendChild(child3);
         StringWriter sw = new StringWriter();
-        DOMElementWriter w =
-            new DOMElementWriter(false,
-                                 DOMElementWriter.XmlNamespacePolicy
-                                 .ONLY_QUALIFY_ELEMENTS);
+        DOMElementWriter w = new DOMElementWriter(false,
+                DOMElementWriter.XmlNamespacePolicy.ONLY_QUALIFY_ELEMENTS);
         w.write(root, sw, 0, "  ");
-        assertEquals("<root xmlns=\"urn:foo\">"
-                     + StringUtils.LINE_SEP
-                     + "  <ns0:child xmlns:ns0=\"urn:foo2\" />"
-                     + StringUtils.LINE_SEP
-                     + "  <ns1:child xmlns:ns1=\"urn:foo2\">"
-                     + StringUtils.LINE_SEP
-                     + "    <ns1:grandchild />"
-                     + StringUtils.LINE_SEP
-                     + "  </ns1:child>"
-                     + StringUtils.LINE_SEP
-                     + "  <ns2:child xmlns:ns2=\"urn:foo2\" />"
-                     + StringUtils.LINE_SEP
-                      + "</root>"
-                     + StringUtils.LINE_SEP, sw.toString());
+        assertEquals(String.format("<root xmlns=\"urn:foo\">%n"
+                + "  <ns0:child xmlns:ns0=\"urn:foo2\" />%n"
+                + "  <ns1:child xmlns:ns1=\"urn:foo2\">%n"
+                + "    <ns1:grandchild />%n"
+                + "  </ns1:child>%n"
+                + "  <ns2:child xmlns:ns2=\"urn:foo2\" />%n"
+                + "</root>%n"), sw.toString());
     }
 }
