@@ -20,11 +20,15 @@ package org.apache.tools.ant.util;
 import java.io.File;
 
 import org.apache.tools.ant.taskdefs.condition.Os;
-import org.junit.Assume;
 import org.junit.Test;
 
+import static org.hamcrest.Matchers.endsWith;
+import static org.hamcrest.Matchers.not;
+import static org.hamcrest.Matchers.startsWith;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertThat;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assume.assumeFalse;
 import static org.junit.Assume.assumeTrue;
 
 /**
@@ -37,7 +41,7 @@ public class JavaEnvUtilsTest {
 
     @Test
     public void testGetExecutableNetware() {
-        Assume.assumeTrue("Test only runs on netware", Os.isName("netware"));
+        assumeTrue("Test only runs on netware", Os.isName("netware"));
         assertEquals("java", JavaEnvUtils.getJreExecutable("java"));
         assertEquals("javac", JavaEnvUtils.getJdkExecutable("javac"));
         assertEquals("foo", JavaEnvUtils.getJreExecutable("foo"));
@@ -46,31 +50,31 @@ public class JavaEnvUtilsTest {
 
     @Test
     public void testGetExecutableWindows() {
-        Assume.assumeTrue("Test only runs on windows", Os.isFamily("windows"));
+        assumeTrue("Test only runs on windows", Os.isFamily("windows"));
         String javaHome = FILE_UTILS.normalize(System.getProperty("java.home"))
             .getAbsolutePath();
 
         String j = JavaEnvUtils.getJreExecutable("java");
-        assertTrue(j.endsWith(".exe"));
+        assertThat(j, endsWith(".exe"));
         assertTrue(j + " is absolute", (new File(j)).isAbsolute());
         try {
-            assertTrue(j + " is normalized and in the JRE dir", j.startsWith(javaHome));
+            assertThat(j + " is normalized and in the JRE dir", j, startsWith(javaHome));
         } catch (AssertionError e) {
             // java.home is bogus
             assertEquals("java.exe", j);
         }
 
         j = JavaEnvUtils.getJdkExecutable("javac");
-        assertTrue(j.endsWith(".exe"));
+        assertThat(j, endsWith(".exe"));
 
         try {
             assertTrue(j + " is absolute", (new File(j)).isAbsolute());
             String javaHomeParent = FILE_UTILS.normalize(javaHome + "/..").getAbsolutePath();
-            assertTrue(j + " is normalized and in the JDK dir", j.startsWith(javaHomeParent));
+            assertThat(j + " is normalized and in the JDK dir", j, startsWith(javaHomeParent));
             if (JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9)) {
-                assertTrue(j + " is normalized and not in the JRE dir", j.startsWith(javaHome));
+                assertThat(j + " is normalized and not in the JRE dir", j, startsWith(javaHome));
             } else {
-                assertTrue(j + " is normalized and not in the JRE dir", !j.startsWith(javaHome));
+                assertThat(j + " is normalized and not in the JRE dir", j, not(startsWith(javaHome)));
             }
         } catch (AssertionError e) {
             // java.home is bogus
@@ -83,33 +87,33 @@ public class JavaEnvUtilsTest {
 
     @Test
     public void testGetExecutableMostPlatforms() {
-        Assume.assumeTrue("Test only runs on non Netware and non Windows systems",
-                !Os.isName("netware") && !Os.isFamily("windows"));
+        assumeFalse("Test only runs on non Netware and non Windows systems",
+                Os.isName("netware") || Os.isFamily("windows"));
         String javaHome = FILE_UTILS.normalize(System.getProperty("java.home")).getAbsolutePath();
 
         // could still be OS/2
         String extension = Os.isFamily("dos") ? ".exe" : "";
 
         String j = JavaEnvUtils.getJreExecutable("java");
-        if (!extension.equals("")) {
-            assertTrue(j.endsWith(extension));
+        if (!extension.isEmpty()) {
+            assertThat(j, endsWith(extension));
         }
         assertTrue(j + " is absolute", (new File(j)).isAbsolute());
-        assertTrue(j + " is normalized and in the JRE dir", j.startsWith(javaHome));
+        assertThat(j + " is normalized and in the JRE dir", j, startsWith(javaHome));
 
         j = JavaEnvUtils.getJdkExecutable("javac");
-        if (!extension.equals("")) {
-            assertTrue(j.endsWith(extension));
+        if (!extension.isEmpty()) {
+            assertThat(j, endsWith(extension));
         }
         assertTrue(j + " is absolute", (new File(j)).isAbsolute());
 
         String javaHomeParent = FILE_UTILS.normalize(javaHome + "/..").getAbsolutePath();
-        assertTrue(j + " is normalized and in the JDK dir", j.startsWith(javaHomeParent));
+        assertThat(j + " is normalized and in the JDK dir", j, startsWith(javaHomeParent));
 
         if (JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9)) {
-            assertTrue(j + " is normalized and in the JRE dir", j.startsWith(javaHome));
+            assertThat(j + " is normalized and in the JRE dir", j, startsWith(javaHome));
         } else {
-            assertTrue(j + " is normalized and not in the JRE dir", !j.startsWith(javaHome));
+            assertThat(j + " is normalized and not in the JRE dir", j, not(startsWith(javaHome)));
         }
 
         assertEquals("foo" + extension, JavaEnvUtils.getJreExecutable("foo"));
@@ -123,6 +127,7 @@ public class JavaEnvUtilsTest {
     }
 
     @Test
+    @SuppressWarnings("deprecation")
     public void isJavaVersionSupportsBothVersionsOfJava9() {
         assumeTrue(JavaEnvUtils.isJavaVersion(JavaEnvUtils.JAVA_9));
         assertTrue("JAVA_1_9 is not considered equal to JAVA_9",
@@ -130,6 +135,7 @@ public class JavaEnvUtilsTest {
     }
 
     @Test
+    @SuppressWarnings("deprecation")
     public void java10IsDetectedProperly() {
         assumeTrue("10".equals(System.getProperty("java.specification.version")));
         assertEquals("10", JavaEnvUtils.getJavaVersion());
