@@ -23,6 +23,7 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
 /**
@@ -30,7 +31,7 @@ import static org.junit.Assert.assertTrue;
  */
 public class LazyFileOutputStreamTest {
     private LazyFileOutputStream los;
-    private final static File f = new File("test.txt");
+    private static final File f = new File("test.txt");
 
     @Before
     public void setUp() {
@@ -49,7 +50,7 @@ public class LazyFileOutputStreamTest {
     @Test
     public void testNoFileWithoutWrite() throws IOException {
         los.close();
-        assertTrue(f + " has not been written.", !f.exists());
+        assertFalse(f + " has not been written.", f.exists());
     }
 
     @Test
