@@ -18,6 +18,9 @@
 
 package org.apache.tools.mail;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+
 import java.io.BufferedReader;
 import java.io.BufferedWriter;
 import java.io.ByteArrayOutputStream;
@@ -28,16 +31,12 @@ import java.io.PrintStream;
 import java.net.InetAddress;
 import java.net.ServerSocket;
 import java.net.Socket;
-import java.util.Enumeration;
 import java.util.Vector;
 
 import org.apache.tools.ant.BuildException;
+import org.junit.AssumptionViolatedException;
 import org.junit.Before;
 import org.junit.Test;
-import org.junit.internal.AssumptionViolatedException;
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
 
 /**
  * JUnit testcases for org.apache.tools.mail.MailMessage.
@@ -565,10 +564,10 @@ public class MailMessageTest {
         protected String subject = null;
         protected String message = null;
 
-        protected Vector replyToList = new Vector();
-        protected Vector toList = new Vector();
-        protected Vector ccList = new Vector();
-        protected Vector bccList = new Vector();
+        protected Vector<String> replyToList = new Vector<>();
+        protected Vector<String> toList = new Vector<>();
+        protected Vector<String> ccList = new Vector<>();
+        protected Vector<String> bccList = new Vector<>();
 
         ClientThread(int port) {
             this.port = port;
@@ -603,26 +602,18 @@ public class MailMessageTest {
             try {
                 msg.from(from);
 
-                Enumeration e;
+                replyToList.forEach(e -> msg.replyto(e));
 
-                e = replyToList.elements();
-                while (e.hasMoreElements()) {
-                    msg.replyto(e.nextElement().toString());
+                for (String e : toList) {
+                    msg.to(e);
                 }
 
-                e = toList.elements();
-                while (e.hasMoreElements()) {
-                    msg.to(e.nextElement().toString());
+                for (String e : ccList) {
+                    msg.cc(e);
                 }
 
-                e = ccList.elements();
-                while (e.hasMoreElements()) {
-                    msg.cc(e.nextElement().toString());
-                }
-
-                e = bccList.elements();
-                while (e.hasMoreElements()) {
-                    msg.bcc(e.nextElement().toString());
+                for (String e : bccList) {
+                    msg.bcc(e);
                 }
 
                 if (subject != null) {
