@@ -25,6 +25,8 @@ import java.nio.ByteBuffer;
 import org.junit.Test;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
 /**
  * Test zip encodings.
@@ -57,8 +59,7 @@ public class ZipEncodingTest {
         // the defined ones
         // retrieved by
         //    awk '/^0x/ && NF>2 {print $1;}' CP1252.TXT
-        byte[] b =
-            new byte[] { 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
+        byte[] b = new byte[] {0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
                          0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F,
                          0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
                          0x18, 0x19, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F,
@@ -104,19 +105,17 @@ public class ZipEncodingTest {
                          (byte) 0xF1, (byte) 0xF2, (byte) 0xF3, (byte) 0xF4,
                          (byte) 0xF5, (byte) 0xF6, (byte) 0xF7, (byte) 0xF8,
                          (byte) 0xF9, (byte) 0xFA, (byte) 0xFB, (byte) 0xFC,
-                         (byte) 0xFD, (byte) 0xFE, (byte) 0xFF };
+                         (byte) 0xFD, (byte) 0xFE, (byte) 0xFF};
 
-        doSimpleEncodingTest("Cp1252",b);
+        doSimpleEncodingTest("Cp1252", b);
     }
 
     private static void assertByteEquals(byte[] expected, ByteBuffer actual) {
 
         assertEquals(expected.length, actual.limit());
 
-        for (int i = 0; i < expected.length; ++i) {
-
-            byte a = actual.get();
-            assertEquals(expected[i], a);
+        for (byte expectedByte : expected) {
+            assertEquals(expectedByte, actual.get());
         }
 
     }
@@ -136,15 +135,15 @@ public class ZipEncodingTest {
 
         String decoded = enc.decode(testBytes);
 
-        assertEquals(true, enc.canEncode(decoded));
+        assertTrue(enc.canEncode(decoded));
 
         ByteBuffer encoded = enc.encode(decoded);
 
         assertByteEquals(testBytes, encoded);
 
-        assertEquals(false, enc.canEncode(UNENC_STRING));
+        assertFalse(enc.canEncode(UNENC_STRING));
         assertByteEquals("%U2016".getBytes("US-ASCII"), enc.encode(UNENC_STRING));
-        assertEquals(false, enc.canEncode(BAD_STRING));
+        assertFalse(enc.canEncode(BAD_STRING));
         assertByteEquals(BAD_STRING_ENC.getBytes("US-ASCII"),
                 enc.encode(BAD_STRING));
     }
